@@ -6,19 +6,17 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: byte_buffer.h 2711 2005-01-12 15:03:47Z mosu $
-
    Byte buffer class
 
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#ifndef __BYTE_BUFFER_H
-#define __BYTE_BUFFER_H
+#ifndef __MTX_COMMON_BYTE_BUFFER_H
+#define __MTX_COMMON_BYTE_BUFFER_H
 
-#include "os.h"
+#include "common/common_pch.h"
 
-#include "common.h"
+#include "common/memory.h"
 
 class byte_buffer_c {
 private:
@@ -58,7 +56,7 @@ public:
     pos = 0;
   }
 
-  void add(unsigned char *new_data, int new_size) {
+  void add(const unsigned char *new_data, int new_size) {
     if ((pos != 0) && ((size + new_size) >= max_size))
       trim();
     data = (unsigned char *)saferealloc(data, size + new_size);
@@ -68,8 +66,7 @@ public:
 
   void remove(int num) {
     if ((pos + num) > size)
-      mxerror("byte_buffer_c: (pos + num) > size. Should not have happened. "
-              "Please file a bug report.\n");
+      mxerror(Y("byte_buffer_c: (pos + num) > size. Should not have happened. Please file a bug report.\n"));
     pos += num;
     if (pos == size) {
       safefree(data);
@@ -88,4 +85,4 @@ public:
   };
 };
 
-#endif // __BYTE_BUFFER_H
+#endif // __MTX_COMMON_BYTE_BUFFER_H
