@@ -11,20 +11,16 @@
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#ifndef __COMPRESSION_H
-#define __COMPRESSION_H
+#ifndef __MTX_COMMON_COMPRESSION_H
+#define __MTX_COMMON_COMPRESSION_H
 
-#include "os.h"
-
-#include <memory>
+#include "common/common_pch.h"
 
 #include <matroska/KaxContentEncoding.h>
 #include <matroska/KaxTracks.h>
 
-#include "common.h"
-#include "common_memory.h"
-#include "error.h"
-#include "smart_pointers.h"
+#include "common/memory.h"
+#include "common/error.h"
 
 using namespace libmatroska;
 
@@ -44,7 +40,7 @@ extern const char *MTX_DLL_API xcompression_methods[];
 
 class MTX_DLL_API compression_error_c: public error_c {
 public:
-  compression_error_c(const string &n_error): error_c(n_error) { }
+  compression_error_c(const std::string &n_error): error_c(n_error) { }
   compression_error_c(const boost::format &n_error): error_c(n_error.str()) { }
 };
 
@@ -170,7 +166,7 @@ struct kax_content_encoding_t {
 
 class MTX_DLL_API content_decoder_c {
 protected:
-  vector<kax_content_encoding_t> encodings;
+  std::vector<kax_content_encoding_t> encodings;
   bool ok;
 
 public:
@@ -185,4 +181,4 @@ public:
   }
 };
 
-#endif // __COMPRESSION_H
+#endif // __MTX_COMMON_COMPRESSION_H
