@@ -45,7 +45,7 @@ kax_analyzer_data_c::to_string() const {
   const EbmlCallbacks *callbacks = find_ebml_callbacks(EBML_INFO(KaxSegment), m_id);
 
   if ((NULL == callbacks) && (EBML_ID(EbmlVoid) == m_id))
-    callbacks = &EBML_INFO(EbmlVoid);
+    callbacks = &EBML_CLASS_CALLBACK(EbmlVoid);
 
   std::string name;
   if (NULL != callbacks)
@@ -83,7 +83,7 @@ kax_analyzer_c::~kax_analyzer_c() {
 }
 
 void
-kax_analyzer_c::log_debug_message(const std::string &message) {
+kax_analyzer_c::_log_debug_message(const std::string &message) {
   mxinfo(message);
 }
 
@@ -305,7 +305,7 @@ kax_analyzer_c::update_element(EbmlElement *e,
   fix_mandatory_elements(e);
 
   try {
-    call_and_validate({},                                 "update_element_0");
+    call_and_validate({},                                  "update_element_0");
     call_and_validate(overwrite_all_instances(EbmlId(*e)), "update_element_1");
     call_and_validate(merge_void_elements(),               "update_element_2");
     call_and_validate(write_element(e, write_defaults),    "update_element_3");
@@ -446,7 +446,7 @@ kax_analyzer_c::handle_void_elements(int data_idx) {
       return false;
 
     binary head[4 + 8];         // Class D + 64 bits coded size
-    unsigned int head_size = EBML_ID_LENGTH(EbmlId(*e));
+    unsigned int head_size = EBML_ID_LENGTH(static_cast<const EbmlId &>(*e));
     EbmlId(*e).Fill(head);
 
     int coded_size = CodedSizeLength(e->GetSize(), e->GetSizeLength() + 1, true);
@@ -889,7 +889,7 @@ kax_analyzer_c::read_all(const EbmlCallbacks &callbacks) {
 
     m_file->setFilePointer(data.m_pos);
     int upper_lvl_el     = 0;
-    EbmlElement *element = es.FindNextElement(EBML_INFO_CONTEXT(EBML_INFO(KaxSegment)), upper_lvl_el, 0xFFFFFFFFL, true);
+    EbmlElement *element = es.FindNextElement(EBML_CLASS_CONTEXT(KaxSegment), upper_lvl_el, 0xFFFFFFFFL, true);
     if (NULL == element)
       continue;
 
@@ -935,7 +935,7 @@ kax_analyzer_c::read_all_meta_seeks() {
     if (EBML_ID(KaxSeekHead) == m_data[i]->m_id)
       read_meta_seek(m_data[i]->m_pos, positions_found);
 
-  sort(m_data.begin(), m_data.end());
+  std::sort(m_data.begin(), m_data.end());
 }
 
 void
