@@ -23,14 +23,11 @@
 #include <stdarg.h>
 #include <stdio.h>
 #include <stdlib.h>
-#if defined(SYS_WINDOWS)
-# include <windows.h>
-# include <direct.h>
-#else
-# include <unistd.h>
-# include <sys/stat.h>
-# include <sys/types.h>
-#endif // SYS_WINDOWS
+#ifdef HAVE_UNISTD_H
+#include <unistd.h>
+#endif
+#include <sys/stat.h>
+#include <sys/types.h>
 
 #include "common/endian.h"
 #include "common/error.h"
@@ -40,7 +37,6 @@
 #include "common/strings/parsing.h"
 
 #if !defined(SYS_WINDOWS)
-
 static std::string
 get_errno_msg() {
   return g_cc_local_utf8->utf8(strerror(errno));
@@ -178,8 +174,8 @@ mm_file_io_c::setFilePointer(int64 offset,
 }
 
 size_t
-mm_file_io_c::write(const void *buffer,
-                    size_t size) {
+mm_file_io_c::_write(const void *buffer,
+                     size_t size) {
   size_t bwritten = fwrite(buffer, 1, size, (FILE *)file);
   if (ferror((FILE *)file) != 0)
     mxerror(boost::format(Y("Could not write to the output file: %1% (%2%)\n")) % errno % get_errno_msg());
@@ -204,8 +200,8 @@ mm_file_io_c::write(const void *buffer,
 }
 
 uint32
-mm_file_io_c::read(void *buffer,
-                   size_t size) {
+mm_file_io_c::_read(void *buffer,
+                    size_t size) {
   int64_t bread = fread(buffer, 1, size, (FILE *)file);
 
 # if HAVE_POSIX_FADVISE
@@ -285,180 +281,7 @@ mm_file_io_c::setup() {
 # endif // HAVE_POSIX_FADVISE
 }
 
-#else // SYS_WINDOWS
-
-HANDLE
-CreateFileUtf8(LPCSTR lpFileName,
-               DWORD dwDesiredAccess,
-               DWORD dwShareMode,
-               LPSECURITY_ATTRIBUTES lpSecurityAttributes,
-               DWORD dwCreationDisposition,
-               DWORD dwFlagsAndAttributes,
-               HANDLE hTemplateFile);
-
-mm_file_io_c::mm_file_io_c(const std::string &path,
-                           const open_mode mode) {
-  DWORD access_mode, share_mode, disposition;
-
-  switch (mode) {
-    case MODE_READ:
-      access_mode = GENERIC_READ;
-      share_mode  = FILE_SHARE_READ | FILE_SHARE_WRITE;
-      disposition = OPEN_EXISTING;
-      break;
-    case MODE_WRITE:
-      access_mode = GENERIC_WRITE | GENERIC_READ;
-      share_mode  = FILE_SHARE_READ;
-      disposition = OPEN_EXISTING;
-      break;
-    case MODE_SAFE:
-      access_mode = GENERIC_WRITE | GENERIC_READ;
-      share_mode  = FILE_SHARE_READ;
-      disposition = OPEN_ALWAYS;
-      break;
-    case MODE_CREATE:
-      access_mode = GENERIC_WRITE;
-      share_mode  = FILE_SHARE_READ;
-      disposition = CREATE_ALWAYS;
-      break;
-    default:
-      throw mm_io_error_c(Y("Unknown open mode"));
-  }
-
-  if ((MODE_WRITE == mode) || (MODE_CREATE == mode))
-    prepare_path(path);
-
-  file = (void *)CreateFileUtf8(path.c_str(), access_mode, share_mode, NULL, disposition, 0, NULL);
-  _eof = false;
-  if ((HANDLE)file == (HANDLE)0xFFFFFFFF)
-    throw mm_io_open_error_c();
-
-  file_name          = path;
-  dos_style_newlines = true;
-}
-
-void
-mm_file_io_c::close() {
-  if (NULL != file) {
-    CloseHandle((HANDLE)file);
-    file = NULL;
-  }
-  file_name = "";
-}
-
-uint64
-mm_file_io_c::get_real_file_pointer() {
-  LONG high = 0;
-  DWORD low = SetFilePointer((HANDLE)file, 0, &high, FILE_CURRENT);
-
-  if ((low == INVALID_SET_FILE_POINTER) && (GetLastError() != NO_ERROR))
-    return (uint64)-1;
-
-  return (((uint64)high) << 32) | (uint64)low;
-}
-
-void
-mm_file_io_c::setFilePointer(int64 offset,
-                             seek_mode mode) {
-  DWORD method = seek_beginning == mode ? FILE_BEGIN
-               : seek_current   == mode ? FILE_CURRENT
-               : seek_end       == mode ? FILE_END
-               :                          FILE_BEGIN;
-  LONG high    = (LONG)(offset >> 32);
-  DWORD low    = SetFilePointer((HANDLE)file, (LONG)(offset & 0xffffffff), &high, method);
-
-  if ((INVALID_SET_FILE_POINTER == low) && (GetLastError() != NO_ERROR))
-    throw mm_io_seek_error_c();
-
-  m_current_position = (int64_t)low + ((int64_t)high << 32);
-}
-
-uint32
-mm_file_io_c::read(void *buffer,
-                   size_t size) {
-  DWORD bytes_read;
-
-  if (!ReadFile((HANDLE)file, buffer, size, &bytes_read, NULL)) {
-    _eof               = true;
-    m_current_position = get_real_file_pointer();
-
-    return 0;
-  }
-
-  if (size != bytes_read)
-    _eof = true;
-
-  m_current_position += bytes_read;
-
-  return bytes_read;
-}
-
-size_t
-mm_file_io_c::write(const void *buffer,
-                    size_t size) {
-  DWORD bytes_written;
-
-  if (!WriteFile((HANDLE)file, buffer, size, &bytes_written, NULL))
-    bytes_written = 0;
-
-  if (bytes_written != size) {
-    std::string error_msg_utf8;
-
-    DWORD error     = GetLastError();
-    char *error_msg = NULL;
-    FormatMessage(FORMAT_MESSAGE_ALLOCATE_BUFFER | FORMAT_MESSAGE_FROM_SYSTEM | FORMAT_MESSAGE_IGNORE_INSERTS, NULL, error, MAKELANGID(LANG_NEUTRAL, SUBLANG_DEFAULT), (LPTSTR)&error_msg, 0, NULL);
-
-    if (NULL != error_msg) {
-      int idx = strlen(error_msg) - 1;
-
-      while ((0 <= idx) && ((error_msg[idx] == '\n') || (error_msg[idx] == '\r'))) {
-        error_msg[idx] = 0;
-        idx--;
-      }
-
-      error_msg_utf8 = g_cc_local_utf8->utf8(error_msg);
-    } else
-      error_msg_utf8 = Y("unknown");
-
-    mxerror(boost::format(Y("Could not write to the output file: %1% (%2%)\n")) % error % error_msg_utf8);
-
-    if (NULL != error_msg)
-      LocalFree(error_msg);
-  }
-
-  m_current_position += bytes_written;
-  cached_size         = -1;
-
-  return bytes_written;
-}
-
-bool
-mm_file_io_c::eof() {
-  return _eof;
-}
-
-int
-mm_file_io_c::truncate(int64_t pos) {
-  cached_size = -1;
-
-  save_pos();
-  if (setFilePointer2(pos)) {
-    bool result = SetEndOfFile((HANDLE)file);
-    restore_pos();
-
-    return result ? 0 : -1;
-  }
-
-  restore_pos();
-
-  return -1;
-}
-
-void
-mm_file_io_c::setup() {
-}
-
-#endif // SYS_UNIX
+#endif // !defined(SYS_WINDOWS)
 
 void
 mm_file_io_c::prepare_path(const std::string &path) {
@@ -617,6 +440,12 @@ mm_io_c::puts(const std::string &s) {
   return num_written;
 }
 
+uint32_t
+mm_io_c::read(void *buffer,
+              size_t size) {
+  return _read(buffer, size);
+}
+
 uint32_t
 mm_io_c::read(std::string &buffer,
               size_t size) {
@@ -795,6 +624,12 @@ mm_io_c::write_uint64_be(uint64_t value) {
   return write(&buffer, sizeof(uint64_t));
 }
 
+size_t
+mm_io_c::write(const void *buffer,
+               size_t size) {
+  return _write(buffer, size);
+}
+
 uint32_t
 mm_io_c::write(const memory_cptr &buffer,
                int size,
@@ -906,6 +741,19 @@ mm_proxy_io_c::close() {
   proxy_io = NULL;
 }
 
+
+uint32
+mm_proxy_io_c::_read(void *buffer,
+                     size_t size) {
+  return proxy_io->read(buffer, size);
+}
+
+size_t
+mm_proxy_io_c::_write(const void *buffer,
+                      size_t size) {
+  return proxy_io->write(buffer, size);
+}
+
 /*
    Dummy class for output to /dev/null. Needed for two pass stuff.
 */
@@ -928,8 +776,8 @@ mm_null_io_c::setFilePointer(int64 offset,
 }
 
 uint32
-mm_null_io_c::read(void *buffer,
-                   size_t size) {
+mm_null_io_c::_read(void *buffer,
+                    size_t size) {
   memset(buffer, 0, size);
   pos += size;
 
@@ -937,8 +785,8 @@ mm_null_io_c::read(void *buffer,
 }
 
 size_t
-mm_null_io_c::write(const void *buffer,
-                    size_t size) {
+mm_null_io_c::_write(const void *buffer,
+                     size_t size) {
   pos += size;
 
   return size;
@@ -1018,8 +866,8 @@ mm_mem_io_c::setFilePointer(int64 offset,
 }
 
 uint32
-mm_mem_io_c::read(void *buffer,
-                  size_t size) {
+mm_mem_io_c::_read(void *buffer,
+                   size_t size) {
   int64_t rbytes = (pos + size) >= mem_size ? mem_size - pos : size;
   if (read_only)
     memcpy(buffer, &ro_mem[pos], rbytes);
@@ -1031,8 +879,8 @@ mm_mem_io_c::read(void *buffer,
 }
 
 size_t
-mm_mem_io_c::write(const void *buffer,
-                   size_t size) {
+mm_mem_io_c::_write(const void *buffer,
+                    size_t size) {
   if (read_only)
     throw error_c(Y("wrong usage: writing to read-only memory"));
 
@@ -1289,35 +1137,20 @@ mm_stdio_c::setFilePointer(int64,
 }
 
 uint32
-mm_stdio_c::read(void *buffer,
-                 size_t size) {
+mm_stdio_c::_read(void *buffer,
+                  size_t size) {
   return fread(buffer, 1, size, stdin);
 }
 
+#if !defined(SYS_WINDOWS)
 size_t
-mm_stdio_c::write(const void *buffer,
-                  size_t size) {
-#if defined(SYS_WINDOWS)
-  int i;
-  int bytes_written = 0;
-  const char *s     = (const char *)buffer;
-  for (i = 0; i < size; ++i)
-    if (('\r' != s[i]) || ((i + 1) == size) || ('\n' != s[i + 1]))
-      bytes_written += fwrite(&s[i], 1, 1, stdout);
-
-  fflush(stdout);
-
-  cached_size = -1;
-
-  return bytes_written;
-
-#else  // defined(SYS_WINDOWS)
-
+mm_stdio_c::_write(const void *buffer,
+                   size_t size) {
   cached_size = -1;
 
   return fwrite(buffer, 1, size, stdout);
-#endif // defined(SYS_WINDOWS)
 }
+#endif // defined(SYS_WINDOWS)
 
 void
 mm_stdio_c::close() {
