@@ -85,8 +85,8 @@ mm_multi_file_io_c::setFilePointer(int64 offset,
 }
 
 uint32
-mm_multi_file_io_c::read(void *buffer,
-                         size_t size) {
+mm_multi_file_io_c::_read(void *buffer,
+                          size_t size) {
   size_t num_read_total     = 0;
   unsigned char *buffer_ptr = static_cast<unsigned char *>(buffer);
 
@@ -116,8 +116,8 @@ mm_multi_file_io_c::read(void *buffer,
 }
 
 size_t
-mm_multi_file_io_c::write(const void *buffer,
-                          size_t size) {
+mm_multi_file_io_c::_write(const void *buffer,
+                           size_t size) {
   throw mm_io_error_c("write-to-multi-file-io-object");
 }
 
@@ -219,7 +219,7 @@ mm_multi_file_io_c::open_multi(const std::string &display_file_name) {
     paths.push_back(path_sorter_t(itr->path(), current_number));
   }
 
-  sort(paths.begin(), paths.end());
+  std::sort(paths.begin(), paths.end());
 
   std::vector<bfs::path> file_names;
   foreach(const path_sorter_t &path, paths)
