@@ -205,12 +205,10 @@ mpeg4::p10::parse_sps(memory_cptr &buffer,
   w.copy_bits(3, r);            // forbidden_zero_bit, nal_ref_idc
   if (w.copy_bits(5, r) != 7)   // nal_unit_type
     return false;
-  sps.profile_idc = w.copy_bits(8, r); // profile_idc
-  if (sps.profile_idc < 0)
-    return false;
+  sps.profile_idc    = w.copy_bits(8, r); // profile_idc
   sps.profile_compat = w.copy_bits(8, r); // constraints
-  sps.level_idc = w.copy_bits(8, r);      // level_idc
-  sps.id = gecopy(r, w);                  // sps id
+  sps.level_idc      = w.copy_bits(8, r); // level_idc
+  sps.id             = gecopy(r, w);      // sps id
   if (sps.profile_idc >= 100) {           // high profile
     if (gecopy(r, w) == 3)                // chroma_format_idc
       w.copy_bits(1, r);                  // residue_transform_flag
@@ -537,6 +535,7 @@ mpeg4::p10::avc_es_parser_c::avc_es_parser_c()
   , m_generate_timecodes(false)
   , m_have_incomplete_frame(false)
   , m_ignore_nalu_size_length_errors(false)
+  , m_discard_actual_frames(false)
   , m_num_slices_by_type(11, 0)
   , m_debug_keyframe_detection(debugging_requested("avc_debug_keyframe_detection"))
 {
@@ -559,6 +558,11 @@ mpeg4::p10::avc_es_parser_c::~avc_es_parser_c() {
       mxinfo(boost::format("  %1%: %2%\n") % s_type_names[i] % m_num_slices_by_type[i]);
 }
 
+void
+mpeg4::p10::avc_es_parser_c::discard_actual_frames(bool discard) {
+  m_discard_actual_frames = discard;
+}
+
 void
 mpeg4::p10::avc_es_parser_c::add_bytes(unsigned char *buffer,
                                        int size) {
@@ -1036,6 +1040,12 @@ mpeg4::p10::avc_es_parser_c::cleanup() {
   if (m_frames.empty())
     return;
 
+  if (m_discard_actual_frames) {
+    m_frames.clear();
+    m_timecodes.clear();
+    return;
+  }
+
   // This may be wrong but is needed for mkvmerge to work correctly
   // (cluster_helper etc).
   i->m_keyframe = true;
@@ -1104,7 +1114,7 @@ mpeg4::p10::avc_es_parser_c::cleanup() {
     return;
   }
 
-  sort(poc.begin(), poc.end(), compare_poc_by_poc);
+  std::sort(poc.begin(), poc.end(), compare_poc_by_poc);
 
   int num_frames    = m_frames.size();
   int num_timecodes = m_timecodes.size();
@@ -1116,7 +1126,7 @@ mpeg4::p10::avc_es_parser_c::cleanup() {
                     :                              0;
   }
 
-  sort(poc.begin(), poc.end(), compare_poc_by_dec);
+  std::sort(poc.begin(), poc.end(), compare_poc_by_dec);
 
   i          = m_frames.begin();
   i->m_start = poc[0].timecode;
