@@ -12,18 +12,15 @@
    Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#include "common/os.h"
+#include "common/common_pch.h"
 
 #include <expat.h>
 #include <ctype.h>
 
-#include <string>
-
 #include <matroska/KaxInfo.h>
 #include <matroska/KaxInfoData.h>
 #include <matroska/KaxSegment.h>
 
-#include "common/common.h"
 #include "common/ebml.h"
 #include "common/error.h"
 #include "common/iso639.h"
@@ -40,10 +37,10 @@ end_segmentinfo_data(void *) {
   EbmlMaster *m;
 
   m = static_cast<EbmlMaster *>(xmlp_pelt);
-  if (m->FindFirstElt(KaxChapterString::ClassInfos, false) == NULL)
+  if (m->FindFirstElt(EBML_INFO(KaxChapterString), false) == NULL)
     xmlp_error(CPDATA, "<ChapterDisplay> is missing the <ChapterString> "
                "child.");
-  if (m->FindFirstElt(KaxChapterLanguage::ClassInfos, false) == NULL) {
+  if (m->FindFirstElt(EBML_INFO(KaxChapterLanguage), false) == NULL) {
     KaxChapterLanguage *cl;
 
     cl = new KaxChapterLanguage;
