@@ -10,7 +10,7 @@
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#include "common/os.h"
+#include "common/common_pch.h"
 
 #include <cassert>
 
@@ -28,7 +28,6 @@
 #include <matroska/KaxTags.h>
 
 #include "common/chapters/chapters.h"
-#include "common/common.h"
 #include "common/ebml.h"
 #include "common/kax_analyzer.h"
 #include "common/math.h"
@@ -49,7 +48,7 @@ find_tag_for_track(int idx,
 
   int i;
   for (i = 0; i < m.ListSize(); i++) {
-    if (EbmlId(*m[i]) != KaxTag::ClassInfos.GlobalId)
+    if (EbmlId(*m[i]) != EBML_ID(KaxTag))
       continue;
 
     int64_t tag_cuid = get_tag_cuid(*static_cast<KaxTag *>(m[i]));
@@ -84,7 +83,7 @@ get_chapter_index(int idx,
   int i;
   std::string sidx = (boost::format("INDEX %|1$02d|") % idx).str();
   for (i = 0; i < atom.ListSize(); i++)
-    if ((EbmlId(*atom[i]) == KaxChapterAtom::ClassInfos.GlobalId) &&
+    if ((EbmlId(*atom[i]) == EBML_ID(KaxChapterAtom)) &&
         (get_chapter_name(*static_cast<KaxChapterAtom *>(atom[i])) == sidx))
       return get_chapter_start(*static_cast<KaxChapterAtom *>(atom[i]));
 
@@ -211,8 +210,8 @@ extract_cuesheet(const std::string &file_name,
   }
 
   KaxChapters all_chapters;
-  KaxChapters *chapters = dynamic_cast<KaxChapters *>(analyzer->read_all(KaxChapters::ClassInfos));
-  KaxTags *all_tags     = dynamic_cast<KaxTags *>(analyzer->read_all(KaxTags::ClassInfos));
+  KaxChapters *chapters = dynamic_cast<KaxChapters *>(analyzer->read_all(EBML_INFO(KaxChapters)));
+  KaxTags *all_tags     = dynamic_cast<KaxTags *>(analyzer->read_all(EBML_INFO(KaxTags)));
 
   if ((NULL != chapters) && (NULL != all_tags)) {
     int i;
