@@ -10,20 +10,14 @@
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#include "common/os.h"
+#include "common/common_pch.h"
 
 #include <cassert>
 #include <iostream>
 #include <stdlib.h>
-#include <string>
-#include <vector>
-
-#include <boost/regex.hpp>
 
 #include "common/chapters/chapters.h"
 #include "common/command_line.h"
-#include "common/common.h"
-#include "common/locale.h"
 #include "common/matroska.h"
 #include "common/mm_io.h"
 #include "common/strings/parsing.h"
