@@ -361,8 +361,6 @@ extract_tracks(const std::string &file_name,
     KaxTags all_tags;
 
     while (NULL != (l1 = file->read_next_level1_element())) {
-      int64_t element_end_pos = l1->GetElementPosition() + l1->ElementSize();
-
       if (EbmlId(*l1) == EBML_ID(KaxInfo)) {
         // General info about this Matroska file
         show_element(l1, 1, Y("Segment information"));
@@ -395,7 +393,8 @@ extract_tracks(const std::string &file_name,
           uint64_t cluster_tc = uint64(*ctc);
           show_element(ctc, 2, boost::format(Y("Cluster timecode: %|1$.3f|s")) % ((float)cluster_tc * (float)tc_scale / 1000000000.0));
           cluster->InitTimecode(cluster_tc, tc_scale);
-        }
+        } else
+          cluster->InitTimecode(0, tc_scale);
 
         int i;
         for (i = 0; cluster->ListSize() > i; ++i) {
@@ -435,7 +434,6 @@ extract_tracks(const std::string &file_name,
 
       }
 
-      in->setFilePointer(element_end_pos, seek_beginning);
       delete l1;
 
     } // while (l1 != NULL)
