@@ -10,14 +10,14 @@
    Written by Matt Rice <topquark@sluggy.net>.
 */
 
-#include "common.h"
-#include "commonebml.h"
+#include "common/common_pch.h"
 
-#include "xtr_avc.h"
+#include "common/ebml.h"
+#include "extract/xtr_avc.h"
 
 static const binary s_start_code[4] = { 0x00, 0x00, 0x00, 0x01 };
 
-xtr_avc_c::xtr_avc_c(const string &codec_id,
+xtr_avc_c::xtr_avc_c(const std::string &codec_id,
                      int64_t tid,
                      track_spec_t &tspec)
   : xtr_base_c(codec_id, tid, tspec)
@@ -58,7 +58,7 @@ xtr_avc_c::create_file(xtr_base_c *master,
   if (mpriv->get_size() < 6)
     mxerror(boost::format(Y("Track %1% CodecPrivate is too small.\n")) % m_tid);
 
-  binary *buf = mpriv->get();
+  binary *buf     = mpriv->get_buffer();
   m_nal_size_size = 1 + (buf[4] & 3);
 
   int pos    = 6;
@@ -89,7 +89,7 @@ xtr_avc_c::handle_frame(memory_cptr &frame,
   m_content_decoder.reverse(frame, CONTENT_ENCODING_SCOPE_BLOCK);
 
   int pos     = 0;
-  binary *buf = (binary *)frame->get();
+  binary *buf = (binary *)frame->get_buffer();
 
   while (frame->get_size() > pos)
     write_nal(buf, pos, frame->get_size(), m_nal_size_size);
