@@ -5,8 +5,6 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: xtr_avc.h 3890 2008-09-13 12:26:13Z mosu $
-
    extracts tracks from Matroska files into other files
 
    Written by Matt Rice <topquark@sluggy.net>.
@@ -15,16 +13,16 @@
 #ifndef __XTR_AVC_H
 #define __XTR_AVC_H
 
-#include "os.h"
+#include "common/common_pch.h"
 
-#include "xtr_base.h"
+#include "extract/xtr_base.h"
 
 class xtr_avc_c: public xtr_base_c {
 private:
   int m_nal_size_size;
 
 public:
-  xtr_avc_c(const string &codec_id, int64_t tid, track_spec_t &tspec);
+  xtr_avc_c(const std::string &codec_id, int64_t tid, track_spec_t &tspec);
 
   virtual void create_file(xtr_base_c *master, KaxTrackEntry &track);
   virtual void handle_frame(memory_cptr &frame, KaxBlockAdditions *additions, int64_t timecode, int64_t duration, int64_t bref, int64_t fref,
