@@ -105,23 +105,15 @@ xtr_ssa_c::create_file(xtr_base_c *master,
   xtr_base_c::create_file(master, track);
   m_out->write_bom(m_sub_charset);
 
-  memory_cptr mpriv = decode_codec_private(priv);
+  memory_cptr mpriv       = decode_codec_private(priv);
 
   const unsigned char *pd = mpriv->get_buffer();
   int priv_size           = mpriv->get_size();
-  int bom_len             = 0;
+  unsigned int bom_len    = 0;
+  byte_order_e byte_order = BO_NONE;
 
   // Skip any BOM that might be present.
-  if ((3 < priv_size) && (0xef == pd[0]) && (0xbb == pd[1]) && (0xbf == pd[2]))
-    bom_len = 3;
-  else if ((4 < priv_size) && (0xff == pd[0]) && (0xfe == pd[1]) && (0x00 == pd[2]) && (0x00 == pd[3]))
-    bom_len = 4;
-  else if ((4 < priv_size) && (0x00 == pd[0]) && (0x00 == pd[1]) && (0xfe == pd[2]) && (0x0ff == pd[3]))
-    bom_len = 4;
-  else if ((2 < priv_size) && (0xff == pd[0]) && (0xfe == pd[1]))
-    bom_len = 2;
-  else if ((2 < priv_size) && (0xfe == pd[0]) && (0xff == pd[1]))
-    bom_len = 2;
+  mm_text_io_c::detect_byte_order_marker(pd, priv_size, byte_order, bom_len);
 
   pd                += bom_len;
   priv_size         -= bom_len;
@@ -152,10 +144,19 @@ xtr_ssa_c::create_file(xtr_base_c *master,
   if (0 > pos2)
     pos2 = sconv.length();
 
-  m_ssa_format = split(sconv.substr(pos1 + 7, pos2 - pos1 - 7), ",");
+  std::string format_line = downcase(sconv.substr(pos1 + 7, pos2 - pos1 - 7));
+  if (std::string::npos == format_line.find("text")) {
+    if (format_line[format_line.length() - 1] == '\r') {
+      format_line.erase(format_line.length() - 1);
+      --pos2;
+    }
+
+    format_line += ",text";
+    sconv.insert(pos2, ", Text");
+  }
+
+  m_ssa_format = split(format_line, ",");
   strip(m_ssa_format, true);
-  for (pos1 = 0; m_ssa_format.size() > pos1; ++pos1)
-    m_ssa_format[pos1] = downcase(m_ssa_format[pos1]);
 
   sconv = m_conv->native(sconv);
   m_out->puts(sconv);
@@ -265,7 +266,7 @@ xtr_ssa_c::finish_file() {
 
   // Sort the SSA lines according to their ReadOrder number and
   // write them.
-  sort(m_lines.begin(), m_lines.end());
+  std::sort(m_lines.begin(), m_lines.end());
   for (i = 0; i < m_lines.size(); i++)
     m_out->puts(m_lines[i].m_line.c_str());
 }
