@@ -88,14 +88,15 @@ typedef struct {
   int64_t size;
 } kax_track_t;
 
-std::vector<kax_track_t *> tracks;
-std::map<unsigned int, kax_track_t *> tracks_by_number, tracks_by_uid;
-bool use_gui         = false;
-bool calc_checksums  = false;
-bool show_summary    = false;
-bool show_hexdump    = false;
-int hexdump_max_size = 16;
-uint64_t tc_scale    = TIMECODE_SCALE;
+std::vector<kax_track_t *> s_tracks;
+std::map<unsigned int, kax_track_t *> s_tracks_by_number, s_tracks_by_uid;
+bool g_use_gui                = false;
+bool g_show_size              = false;
+static bool s_calc_checksums  = false;
+static bool s_show_summary    = false;
+static bool s_show_hexdump    = false;
+static int s_hexdump_max_size = 16;
+static uint64_t s_tc_scale    = TIMECODE_SCALE;
 std::vector<boost::format> g_common_boost_formats;
 
 #define BF_DO(n)                             g_common_boost_formats[n]
@@ -130,10 +131,12 @@ std::vector<boost::format> g_common_boost_formats;
 #define BF_SIMPLE_BLOCK_POSITION             BF_DO(19) // Intentional -- same format.
 #define BF_SIMPLE_BLOCK_SUMMARY              BF_DO(25)
 #define BF_SIMPLE_BLOCK_SUMMARY_V2           BF_DO(26)
-#define BF_HANDLE_ELEMENTS_REC_UNKNOWN       BF_DO(27)
-#define BF_CLUSTER_TIMECODE                  BF_DO(28)
-#define BF_CLUSTER_POSITION                  BF_DO(29)
-#define BF_CLUSTER_PREVIOUS_SIZE             BF_DO(30)
+#define BF_CLUSTER_TIMECODE                  BF_DO(27)
+#define BF_CLUSTER_POSITION                  BF_DO(28)
+#define BF_CLUSTER_PREVIOUS_SIZE             BF_DO(29)
+#define BF_CODEC_STATE                       BF_DO(30)
+#define BF_AT                                BF_DO(31)
+#define BF_SIZE                              BF_DO(32)
 
 void
 init_common_boost_formats() {
@@ -164,27 +167,48 @@ init_common_boost_formats() {
   BF_ADD(Y("Frame with size %1%%2%%3%"));                                                                       // 24 -- BF_SIMPLE_BLOCK_FRAME
   BF_ADD(Y("%1% frame, track %2%, timecode %3% (%4%), size %5%, adler 0x%|6$08x|%7%\n"));                       // 25 -- BF_SIMPLE_BLOCK_SUMMARY
   BF_ADD(Y("[%1% frame for track %2%, timecode %3%]"));                                                         // 26 -- BF_SIMPLE_BLOCK_SUMMARY_V2
-  BF_ADD(Y("(Unknown element: %1%)"));                                                                          // 27 -- BF_HANDLE_ELEMENTS_REC_UNKNOWN
-  BF_ADD(Y("Cluster timecode: %|1$.3f|s"));                                                                     // 28 -- BF_CLUSTER_TIMECODE
-  BF_ADD(Y("Cluster position: %1%"));                                                                           // 29 -- BF_CLUSTER_POSITION
-  BF_ADD(Y("Cluster previous size: %1%"));                                                                      // 30 -- BF_CLUSTER_PREVIOUS_SIZE
+  BF_ADD(Y("Cluster timecode: %|1$.3f|s"));                                                                     // 27 -- BF_CLUSTER_TIMECODE
+  BF_ADD(Y("Cluster position: %1%"));                                                                           // 28 -- BF_CLUSTER_POSITION
+  BF_ADD(Y("Cluster previous size: %1%"));                                                                      // 29 -- BF_CLUSTER_PREVIOUS_SIZE
+  BF_ADD(Y("Codec state: %1%"));                                                                                // 30 -- BF_CODEC_STATE
+  BF_ADD(Y(" at %1%"));                                                                                         // 31 -- BF_AT
+  BF_ADD(Y(" size %1%"));                                                                                       // 32 -- BF_SIZE
+}
+
+std::string
+create_element_text(const std::string &text,
+                    int64_t position,
+                    int64_t size) {
+  std::string additional_text;
+
+  if ((1 < verbose) && (0 <= position))
+    additional_text += (BF_AT % position).str();
+
+  if (g_show_size && (-1 != size)) {
+    if (-2 != size)
+      additional_text += (BF_SIZE % size).str();
+    else
+      additional_text += Y(" size is unknown");
+  }
+
+  return text + additional_text;
 }
 
 void
 add_track(kax_track_t *t) {
-  tracks.push_back(t);
-  tracks_by_number[t->tnum] = t;
-  tracks_by_uid[t->tuid]    = t;
+  s_tracks.push_back(t);
+  s_tracks_by_number[t->tnum] = t;
+  s_tracks_by_uid[t->tuid]    = t;
 }
 
 kax_track_t *
 find_track(int tnum) {
-  return tracks_by_number[tnum];
+  return s_tracks_by_number[tnum];
 }
 
 kax_track_t *
 find_track_by_uid(int tuid) {
-  return tracks_by_uid[tuid];
+  return s_tracks_by_uid[tuid];
 }
 
 void
@@ -199,6 +223,9 @@ set_usage() {
       "  -c, --checksum Calculate and display checksums of frame contents.\n"
       "  -s, --summary  Only show summaries of the contents, not each element.\n"
       "  -x, --hexdump  Show the first 16 bytes of each frame as a hex dump.\n"
+      "  -X, --full-hexdump\n"
+      "                 Show all bytes of each frame as a hex dump.\n"
+      "  -z, --size     Show the size of each element including its header.\n"
       "  --output-charset <charset>\n"
       "                 Output messages in this charset\n"
       "  -r, -o, --redirect-output file.ext\n"
@@ -226,8 +253,8 @@ _show_unknown_element(EbmlStream *es,
 
   int i;
   std::string element_id;
-  for (i = EBML_ID_LENGTH(EbmlId(*e)) - 1; 0 <= i; --i)
-    element_id += (s_bf_show_unknown_element % ((EBML_ID_VALUE(EbmlId(*e)) >> (i * 8)) & 0xff)).str();
+  for (i = EBML_ID_LENGTH(static_cast<const EbmlId &>(*e)) - 1; 0 <= i; --i)
+    element_id += (s_bf_show_unknown_element % ((EBML_ID_VALUE(static_cast<const EbmlId &>(*e)) >> (i * 8)) & 0xff)).str();
 
   std::string s = (BF_SHOW_UNKNOWN_ELEMENT % EBML_NAME(e) % element_id % (e->GetSize() + e->HeadSize())).str();
   _show_element(e, es, true, level, s);
@@ -239,10 +266,15 @@ _show_element(EbmlElement *l,
               bool skip,
               int level,
               const std::string &info) {
-  if (show_summary)
+  if (s_show_summary)
     return;
 
-  ui_show_element(level, info, NULL != l ? (int64_t)l->GetElementPosition() : -1);
+  ui_show_element(level, info,
+                    NULL == l          ? -1
+                  :                      static_cast<int64_t>(l->GetElementPosition()),
+                    NULL == l          ? -1
+                  : !l->IsFiniteSize() ? -2
+                  :                      static_cast<int64_t>(l->GetSizeLength() + EBML_ID_LENGTH(static_cast<const EbmlId &>(*l)) + l->GetSize()));
 
   if ((NULL == l) || !skip)
     return;
@@ -273,7 +305,7 @@ create_hexdump(const unsigned char *buf,
   static boost::format s_bf_create_hexdump(" %|1$02x|");
 
   std::string hex(" hexdump");
-  int bmax = std::max(size, hexdump_max_size);
+  int bmax = std::max(size, s_hexdump_max_size);
   int b;
 
   for (b = 0; b < bmax; ++b)
@@ -303,7 +335,7 @@ parse_args(std::vector<std::string> args,
   verbose = 0;
   file_name = "";
 
-  use_gui = false;
+  g_use_gui = false;
 
   set_usage();
   while (handle_common_cli_args(args, "-o"))
@@ -314,21 +346,23 @@ parse_args(std::vector<std::string> args,
     if ((args[i] == "-g") || (args[i] == "--gui")) {
       if (!ui_graphical_available())
         mxerror("mkvinfo was compiled without GUI support.\n");
-      use_gui = true;
+      g_use_gui = true;
     } else if ((args[i] == "-c") || (args[i] == "--checksum"))
-      calc_checksums = true;
+      s_calc_checksums = true;
     else if ((args[i] == "-C") || (args[i] == "--check-mode")) {
-      calc_checksums = true;
+      s_calc_checksums = true;
       verbose = 4;
     } else if ((args[i] == "-s") || (args[i] == "--summary")) {
-      calc_checksums = true;
-      show_summary = true;
+      s_calc_checksums = true;
+      s_show_summary = true;
     } else if ((args[i] == "-x") || (args[i] == "--hexdump"))
-      show_hexdump = true;
+      s_show_hexdump = true;
     else if ((args[i] == "-X") || (args[i] == "--full-hexdump")) {
-      show_hexdump = true;
-      hexdump_max_size = INT_MAX;
-    } else if (file_name != "")
+      s_show_hexdump = true;
+      s_hexdump_max_size = INT_MAX;
+    } else if ((args[i] == "-z") || (args[i] == "--size"))
+      g_show_size = true;
+    else if (file_name != "")
       mxerror(Y("Only one input file is allowed.\n"));
     else
       file_name = args[i];
@@ -399,7 +433,7 @@ sort_master(EbmlMaster &m) {
 
   for (i = 0; m.ListSize() > i; ++i)
     sort_me.push_back(master_sorter_t(i, m[i]->GetElementPosition()));
-  sort(sort_me.begin(), sort_me.end());
+  std::sort(sort_me.begin(), sort_me.end());
 
   for (i = 0; sort_me.size() > i; ++i)
     tmp.push_back(m[sort_me[i].m_index]);
@@ -426,14 +460,14 @@ read_master(EbmlMaster *m,
 std::string
 format_binary(EbmlBinary &bin,
               int max_len = 10) {
-  int len            = std::max(max_len, (int)bin.GetSize());
+  int len            = std::min(max_len, (int)bin.GetSize());
   const binary *b    = bin.GetBuffer();
-  std::string result = (BF_FORMAT_BINARY_1 % bin.GetSize() % to_hex(b, std::max(max_len, (int)bin.GetSize()))).str();
+  std::string result = (BF_FORMAT_BINARY_1 % bin.GetSize() % to_hex(b, len)).str();
 
   if (len < bin.GetSize())
     result += "...";
 
-  if (calc_checksums)
+  if (s_calc_checksums)
     result += (BF_FORMAT_BINARY_2 % calc_adler32(bin.GetBuffer(), bin.GetSize())).str();
 
   strip(result);
@@ -509,9 +543,10 @@ def_handle(info) {
   // General info about this Matroska file
   show_element(l1, 1, Y("Segment information"));
 
-  upper_lvl_el   = 0;
-  EbmlMaster *m1 = static_cast<EbmlMaster *>(l1);
-  read_master(m1, es, EBML_CONTEXT(l1), upper_lvl_el, l3);
+  upper_lvl_el               = 0;
+  EbmlMaster *m1             = static_cast<EbmlMaster *>(l1);
+  EbmlElement *element_found = NULL;
+  read_master(m1, es, EBML_CONTEXT(l1), upper_lvl_el, element_found);
 
   int i1;
   for (i1 = 0; i1 < m1->ListSize(); i1++) {
@@ -519,15 +554,15 @@ def_handle(info) {
 
     if (is_id(l2, KaxTimecodeScale)) {
       KaxTimecodeScale &ktc_scale = *static_cast<KaxTimecodeScale *>(l2);
-      tc_scale = uint64(ktc_scale);
-      show_element(l2, 2, boost::format(Y("Timecode scale: %1%")) % tc_scale);
+      s_tc_scale = uint64(ktc_scale);
+      show_element(l2, 2, boost::format(Y("Timecode scale: %1%")) % s_tc_scale);
 
     } else if (is_id(l2, KaxDuration)) {
       KaxDuration &duration = *static_cast<KaxDuration *>(l2);
       show_element(l2, 2,
                    boost::format(Y("Duration: %|1$.3f|s (%2%)"))
-                   % (double(duration) * tc_scale / 1000000000.0)
-                   % format_timecode((uint64_t)(double(duration) * tc_scale), 3));
+                   % (double(duration) * s_tc_scale / 1000000000.0)
+                   % format_timecode((uint64_t)(double(duration) * s_tc_scale), 3));
 
     } else if (is_id(l2, KaxMuxingApp)) {
       KaxMuxingApp &muxingapp = *static_cast<KaxMuxingApp *>(l2);
@@ -588,6 +623,8 @@ def_handle(info) {
 
     }
   }
+
+  l2 = element_found;
 }
 
 void
@@ -883,9 +920,10 @@ def_handle(tracks) {
   // contained in this segment.
   show_element(l1, 1, Y("Segment tracks"));
 
-  upper_lvl_el = 0;
-  EbmlMaster *m1 = static_cast<EbmlMaster *>(l1);
-  read_master(m1, es, EBML_CONTEXT(l1), upper_lvl_el, l3);
+  upper_lvl_el               = 0;
+  EbmlMaster *m1             = static_cast<EbmlMaster *>(l1);
+  EbmlElement *element_found = NULL;
+  read_master(m1, es, EBML_CONTEXT(l1), upper_lvl_el, element_found);
 
   int i1;
   for (i1 = 0; i1 < m1->ListSize(); i1++) {
@@ -988,10 +1026,10 @@ def_handle(tracks) {
             fourcc_buffer           = (boost::format(Y(" (format tag: 0x%|1$04x|)")) % get_uint16_le(&wfe->w_format_tag)).str();
           }
 
-          if (calc_checksums && !show_summary)
+          if (s_calc_checksums && !s_show_summary)
             fourcc_buffer += (boost::format(Y(" (adler: 0x%|1$08x|)")) % calc_adler32(c_priv.GetBuffer(), c_priv.GetSize())).str();
 
-          if (show_hexdump)
+          if (s_show_hexdump)
             fourcc_buffer += create_hexdump(c_priv.GetBuffer(), c_priv.GetSize());
 
           show_element(l3, 3, boost::format(Y("CodecPrivate, length %1%%2%")) % c_priv.GetSize() % fourcc_buffer);
@@ -1075,7 +1113,7 @@ def_handle(tracks) {
 
       }
 
-      if (show_summary)
+      if (s_show_summary)
         mxinfo(boost::format(Y("Track %1%: %2%, codec ID: %3%%4%%5%%6%\n"))
                % kax_track_number
                % (  'a' == kax_track_type ? Y("audio")
@@ -1091,20 +1129,23 @@ def_handle(tracks) {
     } else if (!is_global(es, l2, 2))
       show_unknown_element(l2, 2);
   }
+
+  l2 = element_found;
 }
 
 void
 def_handle(seek_head) {
-  if ((verbose < 2) && !use_gui) {
+  if ((verbose < 2) && !g_use_gui) {
     show_element(l1, 1, Y("Seek head (subentries will be skipped)"));
     return;
   }
 
   show_element(l1, 1, Y("Seek head"));
 
-  upper_lvl_el   = 0;
-  EbmlMaster *m1 = static_cast<EbmlMaster *>(l1);
-  read_master(m1, es, EBML_CONTEXT(l1), upper_lvl_el, l3);
+  upper_lvl_el               = 0;
+  EbmlMaster *m1             = static_cast<EbmlMaster *>(l1);
+  EbmlElement *element_found = NULL;
+  read_master(m1, es, EBML_CONTEXT(l1), upper_lvl_el, element_found);
 
   int i1;
   for (i1 = 0; i1 < m1->ListSize(); i1++) {
@@ -1148,6 +1189,8 @@ def_handle(seek_head) {
       show_unknown_element(l2, 2);
 
   } // while (l2 != NULL)
+
+  l2 = element_found;
 }
 
 void
@@ -1159,9 +1202,10 @@ def_handle(cues) {
 
   show_element(l1, 1, "Cues");
 
-  upper_lvl_el   = 0;
-  EbmlMaster *m1 = static_cast<EbmlMaster *>(l1);
-  read_master(m1, es, EBML_CONTEXT(l1), upper_lvl_el, l3);
+  upper_lvl_el               = 0;
+  EbmlMaster *m1             = static_cast<EbmlMaster *>(l1);
+  EbmlElement *element_found = NULL;
+  read_master(m1, es, EBML_CONTEXT(l1), upper_lvl_el, element_found);
 
   int i1;
   for (i1 = 0; i1 < m1->ListSize(); i1++) {
@@ -1177,7 +1221,7 @@ def_handle(cues) {
 
         if (is_id(l3, KaxCueTime)) {
           KaxCueTime &cue_time = *static_cast<KaxCueTime *>(l3);
-          show_element(l3, 3, boost::format(Y("Cue time: %|1$.3f|s")) % (tc_scale * ((float)uint64(cue_time)) / 1000000000.0));
+          show_element(l3, 3, boost::format(Y("Cue time: %|1$.3f|s")) % (s_tc_scale * ((float)uint64(cue_time)) / 1000000000.0));
 
         } else if (is_id(l3, KaxCueTrackPositions)) {
           show_element(l3, 3, Y("Cue track positions"));
@@ -1214,7 +1258,7 @@ def_handle(cues) {
 
                 if (is_id(l5, KaxCueRefTime)) {
                   KaxCueRefTime &cue_rt = *static_cast<KaxCueRefTime *>(l5);
-                  show_element(l5, 5, boost::format(Y("Cue ref time: %|1$.3f|s")) % tc_scale % (((float)uint64(cue_rt)) / 1000000000.0));
+                  show_element(l5, 5, boost::format(Y("Cue ref time: %|1$.3f|s")) % s_tc_scale % (((float)uint64(cue_rt)) / 1000000000.0));
 
                 } else if (is_id(l5, KaxCueRefCluster)) {
                   KaxCueRefCluster &cue_rc = *static_cast<KaxCueRefCluster *>(l5);
@@ -1248,15 +1292,18 @@ def_handle(cues) {
       show_unknown_element(l2, 2);
 
   } // while (l2 != NULL)
+
+  l2 = element_found;
 }
 
 void
 def_handle(attachments) {
   show_element(l1, 1, Y("Attachments"));
 
-  upper_lvl_el   = 0;
-  EbmlMaster *m1 = static_cast<EbmlMaster *>(l1);
-  read_master(m1, es, EBML_CONTEXT(l1), upper_lvl_el, l3);
+  upper_lvl_el               = 0;
+  EbmlMaster *m1             = static_cast<EbmlMaster *>(l1);
+  EbmlElement *element_found = NULL;
+  read_master(m1, es, EBML_CONTEXT(l1), upper_lvl_el, element_found);
 
   int i1;
   for (i1 = 0; i1 < m1->ListSize(); i1++) {
@@ -1299,6 +1346,8 @@ def_handle(attachments) {
       show_unknown_element(l2, 2);
 
   } // while (l2 != NULL)
+
+  l2 = element_found;
 }
 
 void
@@ -1365,11 +1414,11 @@ def_handle2(block_group,
         uint32_t adler   = calc_adler32(data.Buffer(), data.Size());
 
         std::string adler_str;
-        if (calc_checksums)
+        if (s_calc_checksums)
           adler_str = (BF_BLOCK_GROUP_BLOCK_ADLER % adler).str();
 
         std::string hex;
-        if (show_hexdump)
+        if (s_show_hexdump)
           hex = create_hexdump(data.Buffer(), data.Size());
 
         show_element(NULL, 4, BF_BLOCK_GROUP_BLOCK_FRAME % data.Size() % adler_str % hex);
@@ -1382,12 +1431,12 @@ def_handle2(block_group,
 
     } else if (is_id(l3, KaxBlockDuration)) {
       KaxBlockDuration &duration = *static_cast<KaxBlockDuration *>(l3);
-      bduration = ((float)uint64(duration)) * tc_scale / 1000000.0;
-      show_element(l3, 3, BF_BLOCK_GROUP_DURATION % (uint64(duration) * tc_scale / 1000000) % (uint64(duration) * tc_scale % 1000000));
+      bduration = ((float)uint64(duration)) * s_tc_scale / 1000000.0;
+      show_element(l3, 3, BF_BLOCK_GROUP_DURATION % (uint64(duration) * s_tc_scale / 1000000) % (uint64(duration) * s_tc_scale % 1000000));
 
     } else if (is_id(l3, KaxReferenceBlock)) {
       KaxReferenceBlock &k_reference = *static_cast<KaxReferenceBlock *>(l3);
-      int reference                  = int64(k_reference) * tc_scale;
+      int reference                  = int64(k_reference) * s_tc_scale;
 
       if (0 >= reference) {
         bref_found  = true;
@@ -1412,6 +1461,9 @@ def_handle2(block_group,
       KaxReferenceVirtual &ref_virt = *static_cast<KaxReferenceVirtual *>(l3);
       show_element(l3, 3, BF_BLOCK_GROUP_REFERENCE_VIRTUAL % int64(ref_virt));
 
+    } else if (is_id(l3, KaxCodecState)) {
+      show_element(l3, 3, BF_CODEC_STATE % format_binary(*static_cast<KaxCodecState *>(l3)));
+
 #endif // MATROSKA_VERSION >= 2
     } else if (is_id(l3, KaxBlockAdditions)) {
       show_element(l3, 3, Y("Additions"));
@@ -1473,11 +1525,11 @@ def_handle2(block_group,
 
             } else if (is_id(l5, KaxSliceDelay)) {
               KaxSliceDelay &sdelay = *static_cast<KaxSliceDelay *>(l5);
-              show_element(l5, 5, BF_BLOCK_GROUP_SLICE_DELAY % (((float)uint64(sdelay)) * tc_scale / 1000000.0));
+              show_element(l5, 5, BF_BLOCK_GROUP_SLICE_DELAY % (((float)uint64(sdelay)) * s_tc_scale / 1000000.0));
 
             } else if (is_id(l5, KaxSliceDuration)) {
               KaxSliceDuration &sduration = *static_cast<KaxSliceDuration *>(l5);
-              show_element(l5, 5, BF_BLOCK_GROUP_SLICE_DURATION % (((float)uint64(sduration)) * tc_scale / 1000000.0));
+              show_element(l5, 5, BF_BLOCK_GROUP_SLICE_DURATION % (((float)uint64(sduration)) * s_tc_scale / 1000000.0));
 
             } else if (is_id(l5, KaxSliceBlockAddID)) {
               KaxSliceBlockAddID &sbaid = *static_cast<KaxSliceBlockAddID *>(l5);
@@ -1498,7 +1550,7 @@ def_handle2(block_group,
 
   } // while (l3 != NULL)
 
-  if (show_summary) {
+  if (s_show_summary) {
     std::string position;
     int fidx;
 
@@ -1572,21 +1624,21 @@ def_handle2(simple_block,
     uint32_t adler   = calc_adler32(data.Buffer(), data.Size());
 
     std::string adler_str;
-    if (calc_checksums)
+    if (s_calc_checksums)
       adler_str = (BF_SIMPLE_BLOCK_ADLER % adler).str();
 
     std::string hex;
-    if (show_hexdump)
+    if (s_show_hexdump)
       hex = create_hexdump(data.Buffer(), data.Size());
 
-    show_element(NULL, 4, BF_SIMPLE_BLOCK_FRAME % data.Size() % adler_str % hex);
+    show_element(NULL, 3, BF_SIMPLE_BLOCK_FRAME % data.Size() % adler_str % hex);
 
     frame_sizes.push_back(data.Size());
     frame_adlers.push_back(adler);
     frame_pos -= data.Size();
   }
 
-  if (show_summary) {
+  if (s_show_summary) {
     std::string position;
     int fidx;
 
@@ -1620,12 +1672,16 @@ def_handle3(cluster,
             int64_t file_size) {
   cluster = (KaxCluster *)l1;
 
-  if (use_gui)
+  if (g_use_gui)
     ui_show_progress(100 * cluster->GetElementPosition() / file_size, Y("Parsing file"));
 
-  upper_lvl_el   = 0;
-  EbmlMaster *m1 = static_cast<EbmlMaster *>(l1);
-  read_master(m1, es, EBML_CONTEXT(l1), upper_lvl_el, l3);
+  upper_lvl_el               = 0;
+  EbmlMaster *m1             = static_cast<EbmlMaster *>(l1);
+  EbmlElement *element_found = NULL;
+  read_master(m1, es, EBML_CONTEXT(l1), upper_lvl_el, element_found);
+
+  KaxClusterTimecode *cluster_tc = FINDFIRST(m1, KaxClusterTimecode);
+  cluster->InitTimecode(NULL == cluster_tc ? 0 : uint64(*cluster_tc), s_tc_scale);
 
   int i1;
   for (i1 = 0; i1 < m1->ListSize(); i1++) {
@@ -1633,10 +1689,7 @@ def_handle3(cluster,
 
     if (is_id(l2, KaxClusterTimecode)) {
       KaxClusterTimecode &ctc = *static_cast<KaxClusterTimecode *>(l2);
-      int64_t cluster_tc     = uint64(ctc);
-      cluster->InitTimecode(cluster_tc, tc_scale);
-
-      show_element(l2, 2, BF_CLUSTER_TIMECODE % ((float)cluster_tc * (float)tc_scale / 1000000000.0));
+      show_element(l2, 2, BF_CLUSTER_TIMECODE % ((float)uint64(ctc) * (float)s_tc_scale / 1000000000.0));
 
     } else if (is_id(l2, KaxClusterPosition)) {
       KaxClusterPosition &c_pos = *static_cast<KaxClusterPosition *>(l2);
@@ -1659,6 +1712,8 @@ def_handle3(cluster,
       show_unknown_element(l2, 2);
 
   } // while (l2 != NULL)
+
+  l2 = element_found;
 }
 
 void
@@ -1678,7 +1733,7 @@ handle_elements_rec(EbmlStream *es,
     }
 
   if (!found) {
-    show_element(e, level, BF_HANDLE_ELEMENTS_REC_UNKNOWN % EBML_NAME(e));
+    show_unknown_element(e, level);
     return;
   }
 
@@ -1726,26 +1781,32 @@ void
 def_handle(chapters) {
   show_element(l1, 1, Y("Chapters"));
 
-  upper_lvl_el   = 0;
-  EbmlMaster *m1 = static_cast<EbmlMaster *>(l1);
-  read_master(m1, es, EBML_CONTEXT(l1), upper_lvl_el, l3);
+  upper_lvl_el               = 0;
+  EbmlMaster *m1             = static_cast<EbmlMaster *>(l1);
+  EbmlElement *element_found = NULL;
+  read_master(m1, es, EBML_CONTEXT(l1), upper_lvl_el, element_found);
 
   int i1;
   for (i1 = 0; i1 < m1->ListSize(); i1++)
     handle_elements_rec(es, 2, 0, (*m1)[i1], chapter_elements);
+
+  l2 = element_found;
 }
 
 void
 def_handle(tags) {
   show_element(l1, 1, Y("Tags"));
 
-  upper_lvl_el   = 0;
-  EbmlMaster *m1 = static_cast<EbmlMaster *>(l1);
-  read_master(m1, es, EBML_CONTEXT(l1), upper_lvl_el, l3);
+  upper_lvl_el               = 0;
+  EbmlMaster *m1             = static_cast<EbmlMaster *>(l1);
+  EbmlElement *element_found = NULL;
+  read_master(m1, es, EBML_CONTEXT(l1), upper_lvl_el, element_found);
 
   int i1;
   for (i1 = 0; i1 < m1->ListSize(); i1++)
     handle_elements_rec(es, 2, 0, (*m1)[i1], tag_elements);
+
+  l2 = element_found;
 }
 
 void
@@ -1800,6 +1861,8 @@ process_file(const std::string &file_name) {
   EbmlElement *l5 = NULL, *l6 = NULL;
   KaxCluster *cluster;
 
+  s_tc_scale = TIMECODE_SCALE;
+
   // open input file
   mm_io_c *in;
   try {
@@ -1838,7 +1901,7 @@ process_file(const std::string &file_name) {
       }
 
       if (is_id(l0, KaxSegment)) {
-        if (l0->GetSize() == -1)
+        if (!l0->IsFiniteSize())
           show_element(l0, 0, Y("Segment, size unknown"));
         else
           show_element(l0, 0, boost::format(Y("Segment, size %1%")) % l0->GetSize());
@@ -1867,7 +1930,7 @@ process_file(const std::string &file_name) {
 
       else if (is_id(l1, KaxCluster)) {
         show_element(l1, 1, Y("Cluster"));
-        if ((verbose == 0) && !show_summary) {
+        if ((verbose == 0) && !s_show_summary) {
           delete l1;
           delete l0;
           delete es;
@@ -1973,7 +2036,7 @@ main(int argc,
   args = command_line_utf8(argc, argv);
   parse_args(args, initial_file);
 
-  if (use_gui)
+  if (g_use_gui)
     return ui_run(argc, argv);
   else
     return console_main(args);
