@@ -11,60 +11,25 @@
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#include "os.h"
+#include "common/common_pch.h"
 
 #include <algorithm>
 
-#include "common.h"
-#include "error.h"
-#include "id3_common.h"
-#include "r_aac.h"
-#include "p_aac.h"
-#include "output_control.h"
-
-#define PROBESIZE 8192
+#include "common/error.h"
+#include "common/id3.h"
+#include "input/r_aac.h"
+#include "output/p_aac.h"
+#include "merge/output_control.h"
 
 int
 aac_reader_c::probe_file(mm_io_c *io,
-                         int64_t size) {
-  unsigned char buf[PROBESIZE];
-  aac_header_t aacheader;
-  int pos;
-
-  if (size < PROBESIZE)
-    return 0;
-  try {
-    io->setFilePointer(0, seek_beginning);
-    skip_id3v2_tag(*io);
-    if (io->read(buf, PROBESIZE) != PROBESIZE)
-      io->setFilePointer(0, seek_beginning);
-    io->setFilePointer(0, seek_beginning);
-  } catch (...) {
-    return 0;
-  }
-
-  if (parse_aac_adif_header(buf, PROBESIZE, &aacheader))
-    return 1;
-
-  pos = find_aac_header(buf, PROBESIZE, &aacheader, false);
-  if ((0 > pos) || ((pos + aacheader.bytes) >= PROBESIZE)) {
-    pos = find_aac_header(buf, PROBESIZE, &aacheader, true);
-    if ((0 > pos) || ((pos + aacheader.bytes) >= PROBESIZE))
-      return 0;
-    pos = find_aac_header(&buf[pos + aacheader.bytes], PROBESIZE - pos - aacheader.bytes, &aacheader, true);
-    if (0 != pos)
-      return 0;
-  }
-
-  pos = find_aac_header(&buf[pos + aacheader.bytes], PROBESIZE - pos - aacheader.bytes, &aacheader, false);
-  if (0 != pos)
-    return 0;
-
-  return 1;
+                         int64_t size,
+                         int64_t probe_range,
+                         int num_headers) {
+  return (find_valid_headers(io, probe_range, num_headers) != -1) ? 1 : 0;
 }
 
-#define INITCHUNKSIZE   16384
-#define SINITCHUNKSIZE "16384"
+#define INITCHUNKSIZE 16384
 
 aac_reader_c::aac_reader_c(track_info_c &_ti)
   throw (error_c):
@@ -74,7 +39,7 @@ aac_reader_c::aac_reader_c(track_info_c &_ti)
   int adif, detected_profile;
 
   try {
-    io                 = new mm_file_io_c(ti.fname);
+    io                 = new mm_file_io_c(m_ti.m_fname);
     size               = io->get_size();
 
     int tag_size_start = skip_id3v2_tag(*io);
@@ -98,29 +63,29 @@ aac_reader_c::aac_reader_c(track_info_c &_ti)
       adif = 1;
 
     } else {
-      if (find_aac_header(chunk, init_read_len, &aacheader, emphasis_present) != 0)
+      if (find_aac_header(chunk, init_read_len, &aacheader, emphasis_present) < 0)
         throw error_c(boost::format(Y("aac_reader: No valid AAC packet found in the first %1% bytes.\n")) % init_read_len);
       guess_adts_version();
       adif = 0;
     }
 
-    ti.id            = 0;       // ID for this track.
+    m_ti.m_id        = 0;       // ID for this track.
     bytes_processed  = 0;
     detected_profile = aacheader.profile;
 
     if (24000 >= aacheader.sample_rate)
       aacheader.profile = AAC_PROFILE_SBR;
 
-    if (   (map_has_key(ti.all_aac_is_sbr,  0) && ti.all_aac_is_sbr[ 0])
-        || (map_has_key(ti.all_aac_is_sbr, -1) && ti.all_aac_is_sbr[-1]))
+    if (   (map_has_key(m_ti.m_all_aac_is_sbr,  0) && m_ti.m_all_aac_is_sbr[ 0])
+        || (map_has_key(m_ti.m_all_aac_is_sbr, -1) && m_ti.m_all_aac_is_sbr[-1]))
       aacheader.profile = AAC_PROFILE_SBR;
 
-    if (   (map_has_key(ti.all_aac_is_sbr,  0) && !ti.all_aac_is_sbr[ 0])
-        || (map_has_key(ti.all_aac_is_sbr, -1) && !ti.all_aac_is_sbr[-1]))
+    if (   (map_has_key(m_ti.m_all_aac_is_sbr,  0) && !m_ti.m_all_aac_is_sbr[ 0])
+        || (map_has_key(m_ti.m_all_aac_is_sbr, -1) && !m_ti.m_all_aac_is_sbr[-1]))
       aacheader.profile = detected_profile;
 
-    if (   map_has_key(ti.all_aac_is_sbr,  0)
-        || map_has_key(ti.all_aac_is_sbr, -1))
+    if (   map_has_key(m_ti.m_all_aac_is_sbr,  0)
+        || map_has_key(m_ti.m_all_aac_is_sbr, -1))
       sbr_status_set = true;
 
   } catch (...) {
@@ -128,7 +93,7 @@ aac_reader_c::aac_reader_c(track_info_c &_ti)
   }
 
   if (verbose)
-    mxinfo_fn(ti.fname, Y("Using the AAC demultiplexer.\n"));
+    mxinfo_fn(m_ti.m_fname, Y("Using the AAC demultiplexer.\n"));
 }
 
 aac_reader_c::~aac_reader_c() {
@@ -149,13 +114,13 @@ aac_reader_c::create_packetizer(int64_t) {
              "file actually contains SBR AAC. The file will be muxed in the "
              "WRONG way otherwise. Also read mkvmerge's documentation.\n"));
 
-  aacpacketizer = new aac_packetizer_c(this, ti, aacheader.id, aacheader.profile, aacheader.sample_rate, aacheader.channels, emphasis_present);
+  aacpacketizer = new aac_packetizer_c(this, m_ti, aacheader.id, aacheader.profile, aacheader.sample_rate, aacheader.channels, emphasis_present);
   add_packetizer(aacpacketizer);
 
   if (AAC_PROFILE_SBR == aacheader.profile)
     aacpacketizer->set_audio_output_sampling_freq(aacheader.sample_rate * 2);
 
-  mxinfo_tid(ti.fname, 0, Y("Using the AAC output module.\n"));
+  mxinfo_tid(m_ti.m_fname, 0, Y("Using the AAC output module.\n"));
 }
 
 // Try to guess if the MPEG4 header contains the emphasis field (2 bits)
@@ -214,8 +179,25 @@ aac_reader_c::get_progress() {
 
 void
 aac_reader_c::identify() {
-  string verbose_info = string("aac_is_sbr:") + string(AAC_PROFILE_SBR == aacheader.profile ? "true" : "unknown");
+  std::string verbose_info = std::string("aac_is_sbr:") + std::string(AAC_PROFILE_SBR == aacheader.profile ? "true" : "unknown");
 
   id_result_container("AAC");
   id_result_track(0, ID_RESULT_TRACK_AUDIO, "AAC", verbose_info);
 }
+
+int
+aac_reader_c::find_valid_headers(mm_io_c *io,
+                                 int64_t probe_range,
+                                 int num_headers) {
+  try {
+    io->setFilePointer(0, seek_beginning);
+    memory_cptr buf = memory_c::alloc(probe_range);
+    int num_read    = io->read(buf->get_buffer(), probe_range);
+    int pos         = find_consecutive_aac_headers(buf->get_buffer(), num_read, num_headers);
+    io->setFilePointer(0, seek_beginning);
+
+    return pos;
+  } catch (...) {
+    return -1;
+  }
+}
