@@ -6,8 +6,6 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: r_aac.h 3385 2006-11-26 13:07:52Z mosu $
-
    class definitions for the AAC demultiplexer module
 
    Written by Moritz Bunkus <moritz@bunkus.org>.
@@ -16,15 +14,14 @@
 #ifndef __R_AAC_H
 #define __R_AAC_H
 
-#include "os.h"
+#include "common/common_pch.h"
 
 #include <stdio.h>
 
-#include "aac_common.h"
-#include "common.h"
-#include "error.h"
-#include "mm_io.h"
-#include "pr_generic.h"
+#include "common/aac.h"
+#include "common/error.h"
+#include "common/mm_io.h"
+#include "merge/pr_generic.h"
 
 class aac_reader_c: public generic_reader_c {
 private:
@@ -44,10 +41,11 @@ public:
   virtual int get_progress();
   virtual void create_packetizer(int64_t id);
 
-  static int probe_file(mm_io_c *io, int64_t size);
+  static int probe_file(mm_io_c *io, int64_t size, int64_t probe_range, int num_headers);
 
 protected:
   virtual void guess_adts_version();
+  static int find_valid_headers(mm_io_c *io, int64_t probe_range, int num_headers);
 };
 
 #endif // __R_AAC_H
