@@ -6,8 +6,6 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: r_asf.h 3825 2008-08-18 20:03:04Z mosu $
-
    class definitions for the ASF demultiplexer module
 
    Written by Moritz Bunkus <moritz@bunkus.org>.
@@ -16,10 +14,10 @@
 #ifndef __R_ASF_H
 #define __R_ASF_H
 
-#include "os.h"
+#include "common/common_pch.h"
 
-#include "mm_io.h"
-#include "pr_generic.h"
+#include "common/mm_io.h"
+#include "merge/pr_generic.h"
 
 class asf_reader_c: public generic_reader_c {
 public:
