@@ -14,11 +14,8 @@
 #ifndef __R_COREPICTURE_H
 #define __R_COREPICTURE_H
 
-#include "common/os.h"
+#include "common/common_pch.h"
 
-#include <vector>
-
-#include "common/common.h"
 #include "common/corepicture.h"
 #include "common/mm_io.h"
 #include "common/xml/element_parser.h"
