@@ -11,10 +11,9 @@
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#include "os.h"
+#include "common/common_pch.h"
 
-#include "common.h"
-#include "r_flv.h"
+#include "input/r_flv.h"
 
 int
 flv_reader_c::probe_file(mm_io_c *io,
