@@ -75,6 +75,7 @@
 #include "output/p_vobbtn.h"
 #include "output/p_vobsub.h"
 #include "output/p_vorbis.h"
+#include "output/p_vp8.h"
 #include "output/p_wavpack.h"
 
 using namespace libmatroska;
@@ -120,6 +121,21 @@ kax_track_t::handle_packetizer_stereo_mode() {
     ptzr_ptr->set_video_stereo_mode(v_stereo_mode, PARAMETER_SOURCE_CONTAINER);
 }
 
+void
+kax_track_t::handle_packetizer_pixel_dimensions() {
+  if ((0 == v_width) || (0 == v_height))
+    return;
+
+  ptzr_ptr->set_video_pixel_width(v_width);
+  ptzr_ptr->set_video_pixel_height(v_height);
+}
+
+void
+kax_track_t::handle_packetizer_default_duration() {
+  if (0 != default_duration)
+    ptzr_ptr->set_track_default_duration(default_duration);
+}
+
 /*
    Probes a file by simply comparing the first four bytes to the EBML
    head signature.
@@ -582,7 +598,7 @@ kax_reader_c::handle_attachments(mm_io_c *io,
     EbmlElement *l2      = NULL;
     upper_lvl_el         = 0;
 
-    atts->Read(*m_es, EBML_INFO_CONTEXT(EBML_INFO(KaxAttachments)), upper_lvl_el, l2, true);
+    atts->Read(*m_es, EBML_CLASS_CONTEXT(KaxAttachments), upper_lvl_el, l2, true);
 
     int i;
     for (i = 0; i < atts->ListSize(); i++) {
@@ -663,7 +679,7 @@ kax_reader_c::handle_chapters(mm_io_c *io,
     EbmlElement *l2           = NULL;
     upper_lvl_el              = 0;
 
-    tmp_chapters->Read(*m_es, EBML_INFO_CONTEXT(EBML_INFO(KaxChapters)), upper_lvl_el, l2, true);
+    tmp_chapters->Read(*m_es, EBML_CLASS_CONTEXT(KaxChapters), upper_lvl_el, l2, true);
 
     if (NULL == m_chapters)
       m_chapters = new KaxChapters;
@@ -696,7 +712,7 @@ kax_reader_c::handle_tags(mm_io_c *io,
     EbmlElement *l2 = NULL;
     upper_lvl_el    = 0;
 
-    tags->Read(*m_es, EBML_INFO_CONTEXT(EBML_INFO(KaxTags)), upper_lvl_el, l2, true);
+    tags->Read(*m_es, EBML_CLASS_CONTEXT(KaxTags), upper_lvl_el, l2, true);
 
     while (tags->ListSize() > 0) {
       if (!(EbmlId(*(*tags)[0]) == EBML_ID(KaxTag))) {
@@ -762,7 +778,7 @@ kax_reader_c::read_headers_info(EbmlElement *&l1,
   // General info about this Matroska file
   mxverb(2, "matroska_reader: |+ segment information...\n");
 
-  l1->Read(*m_es, EBML_INFO_CONTEXT(EBML_INFO(KaxInfo)), upper_lvl_el, l2, true);
+  l1->Read(*m_es, EBML_CLASS_CONTEXT(KaxInfo), upper_lvl_el, l2, true);
 
   KaxTimecodeScale *ktc_scale = FINDFIRST(l1, KaxTimecodeScale);
   if (NULL != ktc_scale) {
@@ -994,7 +1010,7 @@ kax_reader_c::read_headers_tracks(mm_io_c *io,
 
   EbmlElement *l2 = NULL;
   upper_lvl_el    = 0;
-  l1->Read(*m_es, EBML_INFO_CONTEXT(EBML_INFO(KaxTracks)), upper_lvl_el, l2, true);
+  l1->Read(*m_es, EBML_CLASS_CONTEXT(KaxTracks), upper_lvl_el, l2, true);
 
   KaxTrackEntry *ktentry = FINDFIRST(l1, KaxTrackEntry);
   while (ktentry != NULL) {
@@ -1130,7 +1146,7 @@ kax_reader_c::read_headers_seek_head(EbmlElement *&l0,
   KaxSeekHead &seek_head = *static_cast<KaxSeekHead *>(l1);
 
   int i = 0;
-  seek_head.Read(*m_es, EBML_INFO_CONTEXT(EBML_INFO(KaxSeekHead)), i, el, true);
+  seek_head.Read(*m_es, EBML_CLASS_CONTEXT(KaxSeekHead), i, el, true);
 
   for (i = 0; i < seek_head.ListSize(); i++) {
     if (EbmlId(*seek_head[i]) != EBML_ID(KaxSeek))
@@ -1284,13 +1300,14 @@ kax_reader_c::read_headers() {
     mxerror(Y("matroska_reader: caught exception\n"));
   }
 
-  if (NULL == cluster)          // We have NOT found a cluster!
-    return false;
-
   verify_tracks();
 
-  m_in->setFilePointer(cluster->GetElementPosition(), seek_beginning);
-  delete cluster;
+  if (NULL != cluster) {
+    m_in->setFilePointer(cluster->GetElementPosition(), seek_beginning);
+    delete cluster;
+
+  } else
+    m_in->setFilePointer(0, seek_end);
 
   return true;
 }
@@ -1391,35 +1408,40 @@ kax_reader_c::create_video_packetizer(kax_track_t *t,
            || (t->codec_id == MKV_V_MPEG1)
            || (t->codec_id == MKV_V_MPEG2)
            || (t->codec_id == MKV_V_THEORA)
-           || (t->codec_id == MKV_V_DIRAC)) {
+           || (t->codec_id == MKV_V_DIRAC)
+           || (t->codec_id == MKV_V_VP8)) {
     if ((t->codec_id == MKV_V_MPEG1) || (t->codec_id == MKV_V_MPEG2)) {
       int version = t->codec_id[6] - '0';
       mxinfo_tid(m_ti.m_fname, t->tnum, boost::format(Y("Using the MPEG-%1% video output module.\n")) % version);
-      t->ptzr = add_packetizer(new mpeg1_2_video_packetizer_c(this, nti, version, t->v_frate, t->v_width, t->v_height, t->v_dwidth, t->v_dheight, true));
+      set_track_packetizer(t, new mpeg1_2_video_packetizer_c(this, nti, version, t->v_frate, t->v_width, t->v_height, t->v_dwidth, t->v_dheight, true));
 
     } else if (IS_MPEG4_L2_CODECID(t->codec_id) || IS_MPEG4_L2_FOURCC(t->v_fourcc)) {
       mxinfo_tid(m_ti.m_fname, t->tnum, Y("Using the MPEG-4 part 2 video output module.\n"));
       bool is_native = IS_MPEG4_L2_CODECID(t->codec_id);
-      t->ptzr = add_packetizer(new mpeg4_p2_video_packetizer_c(this, nti, t->v_frate, t->v_width, t->v_height, is_native));
+      set_track_packetizer(t, new mpeg4_p2_video_packetizer_c(this, nti, t->v_frate, t->v_width, t->v_height, is_native));
 
     } else if (t->codec_id == MKV_V_MPEG4_AVC)
       create_mpeg4_p10_video_packetizer(t, nti);
 
     else if (t->codec_id == MKV_V_THEORA) {
       mxinfo_tid(m_ti.m_fname, t->tnum, Y("Using the Theora video output module.\n"));
-      t->ptzr = add_packetizer(new theora_video_packetizer_c(this, nti, t->v_frate, t->v_width, t->v_height));
+      set_track_packetizer(t, new theora_video_packetizer_c(this, nti, t->v_frate, t->v_width, t->v_height));
 
     } else if (t->codec_id == MKV_V_DIRAC) {
       mxinfo_tid(m_ti.m_fname, t->tnum, Y("Using the Dirac video output module.\n"));
-      t->ptzr = add_packetizer(new dirac_video_packetizer_c(this, nti));
+      set_track_packetizer(t, new dirac_video_packetizer_c(this, nti));
+
+    } else if (t->codec_id == MKV_V_VP8) {
+      mxinfo_tid(m_ti.m_fname, t->tnum, Y("Using the VP8 video output module.\n"));
+      set_track_packetizer(t, new vp8_video_packetizer_c(this, nti));
+      t->handle_packetizer_pixel_dimensions();
+      t->handle_packetizer_default_duration();
 
     } else {
       mxinfo_tid(m_ti.m_fname, t->tnum, Y("Using the video output module.\n"));
-      t->ptzr = add_packetizer(new video_packetizer_c(this, nti, t->codec_id.c_str(), t->v_frate, t->v_width, t->v_height));
+      set_track_packetizer(t, new video_packetizer_c(this, nti, t->codec_id.c_str(), t->v_frate, t->v_width, t->v_height));
     }
 
-    t->ptzr_ptr = PTZR(t->ptzr);
-
     t->handle_packetizer_display_dimensions();
     t->handle_packetizer_pixel_cropping();
     t->handle_packetizer_stereo_mode();
@@ -1730,6 +1752,7 @@ kax_reader_c::parse_first_mpeg4_p10_frame(kax_track_t *t,
     avc_es_parser_cptr parser(new avc_es_parser_c);
 
     parser->ignore_nalu_size_length_errors();
+    parser->discard_actual_frames();
     if (map_has_key(m_ti.m_nalu_size_lengths, t->tnum))
       parser->set_nalu_size_length(m_ti.m_nalu_size_lengths[t->tnum]);
     else if (map_has_key(m_ti.m_nalu_size_lengths, -1))
@@ -1761,7 +1784,7 @@ kax_reader_c::create_mpeg4_p10_es_video_packetizer(kax_track_t *t,
     mxinfo_tid(m_ti.m_fname, t->tnum, Y("Using the MPEG-4 part 10 ES video output module.\n"));
 
   mpeg4_p10_es_video_packetizer_c *ptzr = new mpeg4_p10_es_video_packetizer_c(this, nti, parser->get_avcc(), t->v_width, t->v_height);
-  t->ptzr                               = add_packetizer(ptzr);
+  set_track_packetizer(t, ptzr);
 
   ptzr->enable_timecode_generation(false);
   if (t->default_duration)
@@ -1772,7 +1795,7 @@ void
 kax_reader_c::create_mpeg4_p10_video_packetizer(kax_track_t *t,
                                                 track_info_c &nti) {
   if ((0 == nti.m_private_size) || (NULL == nti.m_private_data)) {
-    avc_es_parser_cptr parser = parse_first_mpeg4_p10_frame(t, nti);
+    // avc_es_parser_cptr parser = parse_first_mpeg4_p10_frame(t, nti);
     create_mpeg4_p10_es_video_packetizer(t, nti);
     return;
   }
@@ -1780,7 +1803,7 @@ kax_reader_c::create_mpeg4_p10_video_packetizer(kax_track_t *t,
   if (verbose)
     mxinfo_tid(m_ti.m_fname, t->tnum, Y("Using the MPEG-4 part 10 (AVC) video output module.\n"));
 
-  t->ptzr = add_packetizer(new mpeg4_p10_video_packetizer_c(this, nti, t->v_frate, t->v_width, t->v_height));
+  set_track_packetizer(t, new mpeg4_p10_video_packetizer_c(this, nti, t->v_frate, t->v_width, t->v_height));
 }
 
 void
@@ -1887,11 +1910,9 @@ kax_reader_c::read(generic_packetizer_c *requested_ptzr,
     }
 
     KaxClusterTimecode *ctc = static_cast<KaxClusterTimecode *>(cluster->FindFirstElt(EBML_INFO(KaxClusterTimecode), false));
-    if (NULL == ctc)
-      mxerror(Y("r_matroska: Cluster does not contain a cluster timecode. File is broken. Aborting.\n"));
-
-    uint64_t cluster_tc = uint64(*ctc);
+    uint64_t cluster_tc = NULL != ctc ? uint64(*ctc) : 0;
     cluster->InitTimecode(cluster_tc, m_tc_scale);
+
     if (-1 == m_first_timecode) {
       m_first_timecode = cluster_tc * m_tc_scale;
 
@@ -1912,7 +1933,6 @@ kax_reader_c::read(generic_packetizer_c *requested_ptzr,
         process_block_group(cluster, static_cast<KaxBlockGroup *>(element));
     }
 
-    m_in->setFilePointer(cluster->GetElementPosition() + cluster->ElementSize(), seek_beginning);
     delete cluster;
 
   } catch (...) {
@@ -2078,10 +2098,6 @@ kax_reader_c::process_block_group(KaxCluster *cluster,
     m_last_timecode -= m_first_timecode;
 
   KaxCodecState *codec_state = static_cast<KaxCodecState *>(block_group->FindFirstElt(EBML_INFO(KaxCodecState)));
-  if ((NULL != codec_state) && !hack_engaged(ENGAGE_USE_CODEC_STATE))
-    mxerror_tid(m_ti.m_fname, block_track->tnum,
-                Y("This track uses a Matroska feature called 'Codec state elements'. mkvmerge supports these but "
-                  "this feature has not been turned on with the option '--engage use_codec_state'.\n"));
 
   if ((-1 != block_track->ptzr) && block_track->passthrough) {
     // The handling for passthrough is a bit different. We don't have
@@ -2262,3 +2278,10 @@ kax_reader_c::add_available_track_ids() {
     add_available_track_id(track->tnum);
 }
 
+void
+kax_reader_c::set_track_packetizer(kax_track_t *t,
+                                   generic_packetizer_c *ptzr) {
+  t->ptzr     = add_packetizer(ptzr);
+  t->ptzr_ptr = PTZR(t->ptzr);
+}
+
