@@ -6,8 +6,6 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: r_mp3.h 2809 2005-02-24 21:05:35Z mosu $
-
    class definitions for the MP3 reader module
 
    Written by Moritz Bunkus <moritz@bunkus.org>.
@@ -16,15 +14,14 @@
 #ifndef __R_MP3_H
 #define __R_MP3_H
 
-#include "os.h"
+#include "common/common_pch.h"
 
 #include <stdio.h>
 
-#include "mm_io.h"
-#include "common.h"
-#include "error.h"
+#include "common/mm_io.h"
+#include "common/error.h"
 
-#include "p_mp3.h"
+#include "output/p_mp3.h"
 
 class mp3_reader_c: public generic_reader_c {
 private:
@@ -43,12 +40,10 @@ public:
 
   virtual int get_progress();
 
-  static int probe_file(mm_io_c *io, int64_t size, int64_t probe_range,
-                        int num_headers = 5);
+  static int probe_file(mm_io_c *io, int64_t size, int64_t probe_range, int num_headers = 5);
 
 protected:
-  static int find_valid_headers(mm_io_c *io, int64_t probe_range,
-                                int num_headers);
+  static int find_valid_headers(mm_io_c *io, int64_t probe_range, int num_headers);
 };
 
 #endif  // __R_MP3_H
