@@ -6,8 +6,6 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: r_mpeg_ts.h 3911 2008-09-20 13:51:34Z mosu $
-
    class definitions for the MPEG TS demultiplexer module
 
    Written by Moritz Bunkus <moritz@bunkus.org>.
@@ -16,9 +14,9 @@
 #ifndef __R_MPEG_TS_H
 #define __R_MPEG_TS_H
 
-#include "os.h"
+#include "common/common_pch.h"
 
-#include "pr_generic.h"
+#include "merge/pr_generic.h"
 
 class mpeg_ts_reader_c: public generic_reader_c {
 protected:
@@ -31,4 +29,4 @@ public:
   mpeg_ts_reader_c(track_info_c &n_ti): generic_reader_c(n_ti) { };
 };
 
-#endif  // __T_MPEG_TS_H
+#endif  // __R_MPEG_TS_H
