@@ -14,18 +14,14 @@
 #ifndef __R_QTMP4_H
 #define __R_QTMP4_H
 
-#include "common/os.h"
+#include "common/common_pch.h"
 
 #include <stdio.h>
 
-#include <vector>
-
 #include "common/ac3.h"
-#include "common/common.h"
 #include "common/mm_io.h"
 #include "output/p_video.h"
 #include "input/qtmp4_atoms.h"
-#include "common/smart_pointers.h"
 
 struct qt_durmap_t {
   uint32_t number;
