@@ -16,6 +16,7 @@
 #include <matroska/KaxTrackVideo.h>
 
 #include "common/bit_cursor.h"
+#include "common/ebml.h"
 #include "common/endian.h"
 #include "common/error.h"
 #include "input/r_real.h"
@@ -765,15 +766,13 @@ real_reader_c::set_dimensions(real_demuxer_cptr dmx,
 
     }
 
-    KaxTrackEntry *track_entry = PTZR(dmx->ptzr)->get_track_entry();
-    KaxTrackVideo &video       = GetChild<KaxTrackVideo>(*track_entry);
-
-    *(static_cast<EbmlUInteger *>(&GetChild<KaxVideoPixelWidth>(video)))      = width;
-    *(static_cast<EbmlUInteger *>(&GetChild<KaxVideoPixelHeight>(video)))     = height;
+    KaxTrackVideo &video                                     = GetChild<KaxTrackVideo>(*PTZR(dmx->ptzr)->get_track_entry());
+    GetChildAs<KaxVideoPixelWidth,  EbmlUInteger>(video)     = width;
+    GetChildAs<KaxVideoPixelHeight, EbmlUInteger>(video)     = height;
 
     if ((0 != disp_width) && (0 != disp_height)) {
-      *(static_cast<EbmlUInteger *>(&GetChild<KaxVideoDisplayWidth>(video)))  = disp_width;
-      *(static_cast<EbmlUInteger *>(&GetChild<KaxVideoDisplayHeight>(video))) = disp_height;
+      GetChildAs<KaxVideoDisplayWidth,  EbmlUInteger>(video) = disp_width;
+      GetChildAs<KaxVideoDisplayHeight, EbmlUInteger>(video) = disp_height;
     }
 
     rerender_track_headers();
