@@ -6,8 +6,6 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: r_srt.h 4008 2008-11-01 14:14:06Z mosu $
-
    class definition for the Subripper subtitle reader
 
    Written by Moritz Bunkus <moritz@bunkus.org>.
@@ -16,12 +14,11 @@
 #ifndef __R_SRT_H
 #define __R_SRT_H
 
-#include "os.h"
+#include "common/common_pch.h"
 
-#include "mm_io.h"
-#include "common.h"
-#include "pr_generic.h"
-#include "subtitles.h"
+#include "common/mm_io.h"
+#include "merge/pr_generic.h"
+#include "input/subtitles.h"
 
 class srt_reader_c: public generic_reader_c {
 private:
