@@ -6,24 +6,20 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: r_tta.cpp 3865 2008-08-27 20:38:43Z mosu $
-
    TTA demultiplexer module
 
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#include <stdlib.h>
-#include <stdio.h>
-#include <string.h>
-#include <errno.h>
+#include "common/common_pch.h"
 
-#include "common.h"
-#include "error.h"
-#include "id3_common.h"
-#include "output_control.h"
-#include "p_tta.h"
-#include "r_tta.h"
+#include "common/endian.h"
+#include "common/error.h"
+#include "common/id3.h"
+#include "common/math.h"
+#include "input/r_tta.h"
+#include "merge/output_control.h"
+#include "output/p_tta.h"
 
 int
 tta_reader_c::probe_file(mm_io_c *io,
@@ -53,19 +49,19 @@ tta_reader_c::tta_reader_c(track_info_c &_ti)
   generic_reader_c(_ti) {
 
   try {
-    io   = new mm_file_io_c(ti.fname);
+    io   = new mm_file_io_c(m_ti.m_fname);
     size = io->get_size();
 
-    if (identifying)
+    if (g_identifying)
       return;
 
     int tag_size = skip_id3v2_tag(*io);
     if (0 > tag_size)
-      mxerror(_("tta_reader: tag_size < 0 in the c'tor. %s\n"), BUGMSG);
+      mxerror_fn(m_ti.m_fname, boost::format(Y("tta_reader: tag_size < 0 in the c'tor. %1%\n")) % BUGMSG);
     size -= tag_size;
 
     if (io->read(&header, sizeof(tta_file_header_t)) != sizeof(tta_file_header_t))
-      mxerror(FMT_FN "The file header is too short.\n", ti.fname.c_str());
+      mxerror_fn(m_ti.m_fname, Y("The file header is too short.\n"));
 
     int64_t seek_sum  = io->getFilePointer() + 4 - tag_size;
     size             -= id3_tag_present_at_end(*io);
@@ -78,27 +74,26 @@ tta_reader_c::tta_reader_c(track_info_c &_ti)
       seek_points.push_back(seek_point);
     } while (seek_sum < size);
 
-    mxverb(2, "tta: ch %u bps %u sr %u dl %u seek_sum " LLD " size " LLD " num %u\n",
-           get_uint16_le(&header.channels),
-           get_uint16_le(&header.bits_per_sample),
-           get_uint32_le(&header.sample_rate),
-           get_uint32_le(&header.data_length),
-           seek_sum, size, (unsigned int)seek_points.size());
+    mxverb(2,
+           boost::format("tta: ch %1% bps %2% sr %3% dl %4% seek_sum %5% size %6% num %7%\n")
+           % get_uint16_le(&header.channels)    % get_uint16_le(&header.bits_per_sample)
+           % get_uint32_le(&header.sample_rate) % get_uint32_le(&header.data_length)
+           % seek_sum      % size               % seek_points.size());
 
     if (seek_sum != size)
-      mxerror(FMT_FN "The seek table in this TTA file seems to be broken.\n", ti.fname.c_str());
+      mxerror_fn(m_ti.m_fname, Y("The seek table in this TTA file seems to be broken.\n"));
 
     io->skip(4);
 
     bytes_processed = 0;
     pos             = 0;
-    ti.id           = 0;        // ID for this track.
+    m_ti.m_id       = 0;        // ID for this track.
 
   } catch (...) {
-    throw error_c("tta_reader: Could not open the file.");
+    throw error_c(Y("tta_reader: Could not open the file."));
   }
   if (verbose)
-    mxinfo(FMT_FN "Using the TTA demultiplexer.\n", ti.fname.c_str());
+    mxinfo_fn(m_ti.m_fname, Y("Using the TTA demultiplexer.\n"));
 }
 
 tta_reader_c::~tta_reader_c() {
@@ -110,8 +105,8 @@ tta_reader_c::create_packetizer(int64_t) {
   if (NPTZR() != 0)
     return;
 
-  add_packetizer(new tta_packetizer_c(this, get_uint16_le(&header.channels), get_uint16_le(&header.bits_per_sample), get_uint32_le(&header.sample_rate), ti));
-  mxinfo(FMT_TID "Using the TTA output module.\n", ti.fname.c_str(), (int64_t)0);
+  add_packetizer(new tta_packetizer_c(this, m_ti, get_uint16_le(&header.channels), get_uint16_le(&header.bits_per_sample), get_uint32_le(&header.sample_rate)));
+  mxinfo_tid(m_ti.m_fname, 0, Y("Using the TTA output module.\n"));
 }
 
 file_status_e
@@ -132,7 +127,7 @@ tta_reader_c::read(generic_packetizer_c *,
   memory_cptr mem(new memory_c(buf, nread, true));
   if (seek_points.size() <= pos) {
     double samples_left = (double)get_uint32_le(&header.data_length) - (seek_points.size() - 1) * TTA_FRAME_TIME * get_uint32_le(&header.sample_rate);
-    mxverb(2, "tta: samples_left %f\n", samples_left);
+    mxverb(2, boost::format("tta: samples_left %1%\n") % samples_left);
 
     PTZR0->process(new packet_t(mem, -1, irnd(samples_left * 1000000000.0l / get_uint32_le(&header.sample_rate))));
   } else
