@@ -6,8 +6,6 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: r_tta.h 2809 2005-02-24 21:05:35Z mosu $
-
    class definitions for the TTA demultiplexer module
 
    Written by Moritz Bunkus <moritz@bunkus.org>.
@@ -16,22 +14,21 @@
 #ifndef __R_TTA_H
 #define __R_TTA_H
 
-#include "os.h"
+#include "common/common_pch.h"
 
 #include <stdio.h>
 
-#include "common.h"
-#include "error.h"
-#include "mm_io.h"
-#include "pr_generic.h"
-#include "tta_common.h"
+#include "common/error.h"
+#include "common/mm_io.h"
+#include "merge/pr_generic.h"
+#include "common/tta.h"
 
 class tta_reader_c: public generic_reader_c {
 private:
   unsigned char *chunk;
   mm_io_c *io;
   int64_t bytes_processed, size;
-  vector<uint32_t> seek_points;
+  std::vector<uint32_t> seek_points;
   int pos;
   tta_file_header_t header;
 
