@@ -6,27 +6,22 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: r_vobbtn.cpp 3950 2008-09-30 22:35:14Z mosu $
-
    VobBtn stream reader
 
    Written by Steve Lhomme <steve.lhomme@free.fr>.
    Modified by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#include <ctype.h>
-#include <stdlib.h>
-#include <stdio.h>
-#include <string.h>
-#include <errno.h>
+#include "common/common_pch.h"
 
-#include "common.h"
-#include "mm_io.h"
-#include "output_control.h"
-#include "p_vobbtn.h"
-#include "r_vobbtn.h"
+#include "common/endian.h"
+#include "common/mm_io.h"
+#include "common/strings/formatting.h"
+#include "common/strings/parsing.h"
+#include "input/r_vobbtn.h"
+#include "merge/output_control.h"
+#include "output/p_vobbtn.h"
 
-using namespace std;
 
 int
 vobbtn_reader_c::probe_file(mm_io_c *io,
@@ -55,7 +50,7 @@ vobbtn_reader_c::vobbtn_reader_c(track_info_c &_ti)
   generic_reader_c(_ti) {
 
   try {
-    btn_file = new mm_file_io_c(ti.fname);
+    btn_file = new mm_file_io_c(m_ti.m_fname);
     size     = btn_file->get_size();
   } catch (...) {
     throw error_c(Y("vobbtn_reader: Could not open the file."));
@@ -69,7 +64,7 @@ vobbtn_reader_c::vobbtn_reader_c(track_info_c &_ti)
   btn_file->setFilePointer(16, seek_beginning);
 
   if (verbose)
-    mxinfo_fn(ti.fname, Y("Using the VobBtn button reader.\n"));
+    mxinfo_fn(m_ti.m_fname, Y("Using the VobBtn button reader.\n"));
 }
 
 vobbtn_reader_c::~vobbtn_reader_c() {
@@ -78,9 +73,9 @@ vobbtn_reader_c::~vobbtn_reader_c() {
 
 void
 vobbtn_reader_c::create_packetizer(int64_t tid) {
-  ti.id = tid;
+  m_ti.m_id = tid;
   if (demuxing_requested('s', tid))
-    add_packetizer(new vobbtn_packetizer_c(this, ti, width, height));
+    add_packetizer(new vobbtn_packetizer_c(this, m_ti, width, height));
 }
 
 file_status_e
