@@ -15,19 +15,16 @@
 #ifndef __R_WAV_H
 #define __R_WAV_H
 
-#include "common/os.h"
+#include "common/common_pch.h"
 
 #include <stdio.h>
 
-#include "common/common.h"
 #include "common/dts.h"
 #include "common/error.h"
 #include "common/mm_io.h"
 #include "merge/pr_generic.h"
 
-extern "C" {
-#include "avilib.h"
-}
+#include <avilib.h>
 
 class wav_reader_c;
 
