@@ -14,19 +14,16 @@
 #ifndef __SUBTITLES_H
 #define __SUBTITLES_H
 
-#include "os.h"
+#include "common/common_pch.h"
 
-#include <string>
-#include <vector>
-
-#include "output_control.h"
-#include "p_textsubs.h"
+#include "merge/output_control.h"
+#include "output/p_textsubs.h"
 
 typedef struct sub_t {
   int64_t start, end;
-  string subs;
+  std::string subs;
 
-  sub_t(int64_t _start, int64_t _end, const string &_subs):
+  sub_t(int64_t _start, int64_t _end, const std::string &_subs):
     start(_start), end(_end), subs(_subs) {
   }
 
@@ -37,14 +34,14 @@ typedef struct sub_t {
 
 class subtitles_c {
 private:
-  deque<sub_t> entries;
-  deque<sub_t>::iterator current;
+  std::deque<sub_t> entries;
+  std::deque<sub_t>::iterator current;
 
 public:
   subtitles_c() {
     current = entries.end();
   }
-  void add(int64_t start, int64_t end, const string &subs) {
+  void add(int64_t start, int64_t end, const std::string &subs) {
     entries.push_back(sub_t(start, end, subs));
   }
   void reset() {
@@ -107,14 +104,14 @@ protected:
   mm_text_io_c *m_io;
   const std::string &m_file_name;
   int64_t m_tid;
-  int m_cc_utf8;
+  charset_converter_cptr m_cc_utf8;
   std::vector<std::string> m_format;
   bool m_is_ass;
   std::string m_global;
   int64_t m_attachment_id;
 
 public:
-  vector<attachment_t> m_attachments;
+  std::vector<attachment_t> m_attachments;
 
 public:
   ssa_parser_c(generic_reader_c *reader, mm_text_io_c *io, const std::string &file_name, int64_t tid);
@@ -124,7 +121,7 @@ public:
     return m_is_ass;
   }
 
-  void set_iconv_handle(int cc_utf8) {
+  void set_charset_converter(charset_converter_cptr cc_utf8) {
     m_cc_utf8 = cc_utf8;
   }
 
@@ -141,8 +138,8 @@ public:
 
 protected:
   int64_t parse_time(std::string &time);
-  string get_element(const char *index, std::vector<std::string> &fields);
-  string recode_text(std::vector<std::string> &fields);
+  std::string get_element(const char *index, std::vector<std::string> &fields);
+  std::string recode_text(std::vector<std::string> &fields);
   void add_attachment_maybe(std::string &name, std::string &data_uu, ssa_section_e section);
   void decode_chars(unsigned char c1, unsigned char c2, unsigned char c3, unsigned char c4, memory_cptr &buffer, int bytes_to_add, int &allocated);
 };
