@@ -381,7 +381,7 @@ cluster_helper_c::render() {
     if (NULL != new_block_group) {
       // Set the reference priority if it was wanted.
       if ((0 < pack->ref_priority) && new_block_group->replace_simple_by_group())
-        *static_cast<EbmlUInteger *>(&GetChild<KaxReferencePriority>(*new_block_group)) = pack->ref_priority;
+        GetChildAs<KaxReferencePriority, EbmlUInteger>(*new_block_group) = pack->ref_priority;
 
       // Handle BlockAdditions if needed
       if (!pack->data_adds.empty() && new_block_group->ReplaceSimpleByGroup()) {
@@ -390,7 +390,7 @@ cluster_helper_c::render() {
         int data_add_idx;
         for (data_add_idx = 0; pack->data_adds.size() > data_add_idx; ++data_add_idx) {
           KaxBlockMore &block_more                                           = AddEmptyChild<KaxBlockMore>(additions);
-          *static_cast<EbmlUInteger *>(&GetChild<KaxBlockAddID>(block_more)) = data_add_idx + 1;
+          GetChildAs<KaxBlockAddID, EbmlUInteger>(block_more) = data_add_idx + 1;
 
           GetChild<KaxBlockAdditional>(block_more).CopyBuffer((binary *)pack->data_adds[data_add_idx]->get_buffer(), pack->data_adds[data_add_idx]->get_size());
         }
@@ -456,6 +456,8 @@ cluster_helper_c::render() {
   m_min_timecode_in_cluster = -1;
   m_max_timecode_in_cluster = -1;
 
+  m_cluster->delete_non_blocks();
+
   return 1;
 }
 
