@@ -56,6 +56,7 @@
 #include "common/tags/parser.h"
 #include "common/unique_numbers.h"
 #include "common/version.h"
+#include "common/webm.h"
 #include "merge/cluster_helper.h"
 #include "merge/mkvmerge.h"
 #include "merge/output_control.h"
@@ -88,6 +89,7 @@ init_input_file_type_list() {
 #endif
   s_input_file_types.push_back(ext_file_type_t("h264", Y("AVC/h.264 elementary streams")));
   s_input_file_types.push_back(ext_file_type_t("idx",  Y("VobSub subtitles")));
+  s_input_file_types.push_back(ext_file_type_t("ivf",  Y("IVF with VP8")));
   s_input_file_types.push_back(ext_file_type_t("m1v",  Y("MPEG-1 video elementary stream")));
   s_input_file_types.push_back(ext_file_type_t("m2v",  Y("MPEG-2 video elementary stream")));
   s_input_file_types.push_back(ext_file_type_t("mkv",  Y("general Matroska files")));
@@ -102,6 +104,7 @@ init_input_file_type_list() {
   s_input_file_types.push_back(ext_file_type_t("tta",  Y("TTA lossless audio")));
   s_input_file_types.push_back(ext_file_type_t("vc1",  Y("VC1 video elementary stream")));
   s_input_file_types.push_back(ext_file_type_t("wav",  Y("WAVE (uncompressed PCM)")));
+  s_input_file_types.push_back(ext_file_type_t("webm", Y("WebM audio/video files")));
   s_input_file_types.push_back(ext_file_type_t("wv",   Y("WAVPACK lossless audio")));
 }
 
@@ -116,6 +119,7 @@ set_usage() {
   usage_text += Y("  -v, --verbose            verbose status\n");
   usage_text += Y("  -q, --quiet              suppress status output\n");
   usage_text += Y("  -o, --output out         Write to the file 'out'.\n");
+  usage_text += Y("  -w, --webm               Create WebM compliant file.\n");
   usage_text += Y("  --title <title>          Title for this output file.\n");
   usage_text += Y("  --global-tags <file>     Read global tags from a XML file.\n");
   usage_text +=   "\n";
@@ -144,8 +148,7 @@ set_usage() {
                   "                           put at most n milliseconds of data into each\n"
                   "                           cluster.\n");
   usage_text += Y("  --no-cues                Do not write the cue data (the index).\n");
-  usage_text += Y("  --no-clusters-in-meta-seek\n"
-                  "                           Do not write meta seek data for clusters.\n");
+  usage_text += Y("  --clusters-in-meta-seek  Write meta seek data for clusters.\n");
   usage_text += Y("  --disable-lacing         Do not Use lacing.\n");
   usage_text += Y("  --enable-durations       Enable block durations for all blocks.\n");
   usage_text += Y("  --append-to <SFID1:STID1:DFID1:DTID1,SFID2:STID2:DFID2:DTID2,...>\n"
@@ -1602,9 +1605,8 @@ parse_args(std::vector<std::string> args) {
   // Now parse options that are needed right at the beginning.
   mxforeach(sit, args) {
     const std::string &this_arg = *sit;
-    std::string next_arg        = ((sit + 1) == args.end()) ? "" : *(sit + 1);
-
-    bool no_next_arg       = (sit + 1) == args.end();
+    bool no_next_arg            = (sit + 1) == args.end();
+    std::string next_arg        = no_next_arg ? "" : *(sit + 1);
 
     if ((this_arg == "-o") || (this_arg == "--output")) {
       if (no_next_arg)
@@ -1621,7 +1623,9 @@ parse_args(std::vector<std::string> args) {
         mxerror(Y("'--engage' lacks its argument.\n"));
       engage_hacks(next_arg);
       sit++;
-    }
+
+    } else if ((this_arg == "-w") || (this_arg == "--webm"))
+      set_output_compatibility(OC_WEBM);
   }
 
   if (g_outfile.empty()) {
@@ -1629,6 +1633,11 @@ parse_args(std::vector<std::string> args) {
     usage(2);
   }
 
+  if (!outputting_webm() && is_webm_file_name(g_outfile)) {
+    set_output_compatibility(OC_WEBM);
+    mxinfo(boost::format(Y("Automatically enabling WebM compliance mode due to output file name extension.\n")));
+  }
+
   track_info_c *ti      = new track_info_c;
   bool inputs_found     = false;
   bool append_next_file = false;
@@ -1636,9 +1645,8 @@ parse_args(std::vector<std::string> args) {
 
   mxforeach(sit, args) {
     const std::string &this_arg = *sit;
-    std::string next_arg        = ((sit + 1) == args.end()) ? "" : *(sit + 1);
-
-    bool no_next_arg       = (sit + 1) == args.end();
+    bool no_next_arg            = (sit + 1) == args.end();
+    std::string next_arg        = no_next_arg ? "" : *(sit + 1);
 
     // Ignore the options we took care of in the first step.
     if (   (this_arg == "-o")
@@ -1649,6 +1657,10 @@ parse_args(std::vector<std::string> args) {
       continue;
     }
 
+    if (   (this_arg == "-w")
+        || (this_arg == "--webm"))
+      continue;
+
     // Global options
     if ((this_arg == "--priority")) {
       if (no_next_arg)
@@ -1721,8 +1733,8 @@ parse_args(std::vector<std::string> args) {
     } else if (this_arg == "--no-cues")
       g_write_cues = false;
 
-    else if (this_arg == "--no-clusters-in-meta-seek")
-      g_write_meta_seek_for_clusters = false;
+    else if (this_arg == "--clusters-in-meta-seek")
+      g_write_meta_seek_for_clusters = true;
 
     else if (this_arg == "--disable-lacing")
       g_no_lacing = true;
@@ -2154,6 +2166,7 @@ init_globals() {
 static void
 setup() {
   mtx_common_init();
+  g_kax_tracks = new KaxTracks();
 
 #if defined(SYS_UNIX) || defined(COMP_CYGWIN) || defined(SYS_APPLE)
   signal(SIGUSR1, sighandler);
