@@ -83,6 +83,7 @@
 #include "input/r_dts.h"
 #include "input/r_flac.h"
 #include "input/r_flv.h"
+#include "input/r_ivf.h"
 #include "input/r_matroska.h"
 #include "input/r_mp3.h"
 #include "input/r_mpeg_es.h"
@@ -105,6 +106,7 @@
 #include "merge/mkvmerge.h"
 #include "merge/output_control.h"
 #include "merge/debugging.h"
+#include "merge/webm.h"
 
 using namespace libmatroska;
 
@@ -138,7 +140,7 @@ int64_t g_max_ns_per_cluster                = 2000000000;
 bool g_write_cues                           = true;
 bool g_cue_writing_requested                = false;
 generic_packetizer_c *g_video_packetizer    = NULL;
-bool g_write_meta_seek_for_clusters         = true;
+bool g_write_meta_seek_for_clusters         = false;
 bool g_no_lacing                            = false;
 bool g_no_linking                           = true;
 bool g_use_durations                        = false;
@@ -155,7 +157,7 @@ bool g_identify_verbose                     = false;
 bool g_identify_for_mmg                     = false;
 
 KaxSegment *g_kax_segment                   = NULL;
-KaxTracks g_kax_tracks;
+KaxTracks *g_kax_tracks                     = NULL;
 KaxTrackEntry *g_kax_last_entry             = NULL;
 KaxCues *g_kax_cues                         = NULL;
 KaxSeekHead *g_kax_sh_main                  = NULL;
@@ -270,7 +272,7 @@ sighandler(int signum) {
 
   if ((g_kax_sh_main->ListSize() > 0) && !hack_engaged(ENGAGE_NO_META_SEEK)) {
     g_kax_sh_main->UpdateSize();
-    if (s_kax_sh_void->ReplaceWith(*g_kax_sh_main, *s_out, true) == 0)
+    if (s_kax_sh_void->ReplaceWith(*g_kax_sh_main, *s_out, true) == INVALID_FILEPOS_T)
       mxwarn(boost::format(Y("This should REALLY not have happened. The space reserved for the first meta seek element was too small. %1%\n")) % BUGMSG);
   }
   mxinfo(Y(" done\n"));
@@ -332,6 +334,8 @@ get_file_type(filelist_t &file) {
     type = FILE_TYPE_VC1;
   else if (wavpack_reader_c::probe_file(io, size))
     type = FILE_TYPE_WAVPACK4;
+  else if (ivf_reader_c::probe_file(io, size))
+    type = FILE_TYPE_IVF;
   else if (dirac_es_reader_c::probe_file(io, size))
     type = FILE_TYPE_DIRAC;
   // File types that are misdetected sometimes
@@ -548,17 +552,17 @@ render_headers(mm_io_c *out) {
 
     bool first_file                                       = (1 == g_file_num);
 
-    GetChildAs<EDocType, EbmlString>(head)                = "matroska";
+    GetChildAs<EDocType, EbmlString>(head)                = outputting_webm() ? "webm" : "matroska";
     if (hack_engaged(ENGAGE_NO_SIMPLE_BLOCKS)) {
-      GetChildAs<EDocTypeVersion, EbmlUInteger>(head)     = 1;
+      GetChildAs<EDocTypeVersion,     EbmlUInteger>(head) = 1;
       GetChildAs<EDocTypeReadVersion, EbmlUInteger>(head) = 1;
 
     } else {
-      GetChildAs<EDocTypeVersion, EbmlUInteger>(head)     = 2;
+      GetChildAs<EDocTypeVersion,     EbmlUInteger>(head) = 2;
       GetChildAs<EDocTypeReadVersion, EbmlUInteger>(head) = 2;
     }
 
-    head.Render(*out);
+    head.Render(*out, true);
 
     s_kax_infos = &GetChild<KaxInfo>(*g_kax_segment);
 
@@ -686,14 +690,18 @@ render_headers(mm_io_c *out) {
     g_kax_sh_main->IndexThis(*s_kax_infos, *g_kax_segment);
 
     if (!g_packetizers.empty()) {
-      g_kax_segment->PushElement(g_kax_tracks);
-      g_kax_tracks.Render(*out, !hack_engaged(ENGAGE_NO_DEFAULT_HEADER_VALUES));
-      g_kax_sh_main->IndexThis(g_kax_tracks, *g_kax_segment);
+      g_kax_tracks->UpdateSize(true);
+      uint64_t full_header_size = g_kax_tracks->ElementSize(true);
+      g_kax_tracks->UpdateSize(false);
+
+      g_kax_segment->PushElement(*g_kax_tracks);
+      g_kax_tracks->Render(*out, false);
+      g_kax_sh_main->IndexThis(*g_kax_tracks, *g_kax_segment);
 
       // Reserve some small amount of space for header changes by the
       // packetizers.
       s_void_after_track_headers = new EbmlVoid;
-      s_void_after_track_headers->SetSize(1024);
+      s_void_after_track_headers->SetSize(1024 + full_header_size - g_kax_tracks->ElementSize(false));
       s_void_after_track_headers->Render(*out);
     }
 
@@ -709,13 +717,13 @@ render_headers(mm_io_c *out) {
 */
 void
 rerender_track_headers() {
-  g_kax_tracks.UpdateSize(!hack_engaged(ENGAGE_NO_DEFAULT_HEADER_VALUES));
+  g_kax_tracks->UpdateSize(false);
 
   int64_t new_void_size = s_void_after_track_headers->GetElementPosition() + s_void_after_track_headers->GetSize()
-    - g_kax_tracks.GetElementPosition() - g_kax_tracks.ElementSize();
+    - g_kax_tracks->GetElementPosition() - g_kax_tracks->ElementSize();
 
-  s_out->save_pos(g_kax_tracks.GetElementPosition());
-  g_kax_tracks.Render(*s_out, !hack_engaged(ENGAGE_NO_DEFAULT_HEADER_VALUES));
+  s_out->save_pos(g_kax_tracks->GetElementPosition());
+  g_kax_tracks->Render(*s_out, false);
 
   delete s_void_after_track_headers;
   s_void_after_track_headers = new EbmlVoid;
@@ -814,7 +822,7 @@ check_append_mapping() {
   // available (in which case we fill in default ones) or if there are fewer
   // mappings than tracks that are to be copied (which is an error).
   mxforeach(src_file, g_files) {
-    file_id = distance(g_files.begin(), src_file);
+    file_id = std::distance(g_files.begin(), src_file);
     if (!src_file->appending)
       continue;
 
@@ -1056,6 +1064,9 @@ create_readers() {
           file.reader = new flac_reader_c(*file.ti);
           break;
 #endif
+        case FILE_TYPE_IVF:
+          file.reader = new ivf_reader_c(*file.ti);
+          break;
         case FILE_TYPE_MATROSKA:
           file.reader = new kax_reader_c(*file.ti);
           break;
@@ -1239,6 +1250,69 @@ add_tags_from_cue_chapters() {
   g_tags_from_cue_chapters = NULL;
 }
 
+/** \brief Render an EbmlVoid element as a placeholder for chapters
+
+    Chapters cannot be rendered at the start of the file until the
+    file's actual length is known during \c finish_file(). However,
+    the maximum size of chapters is know. So we reserve space at the
+    beginning of the file for all of the chapters.
+
+    WebM compliant files must not contain chapters. This function
+    issues a warning and invalidates the chapters if this is the case.
+ */
+static void
+render_chapter_void_placeholder() {
+  if (0 >= s_max_chapter_size)
+    return;
+
+  if (outputting_webm()) {
+    mxwarn(boost::format(Y("Chapters are not allowed in WebM compliant files. No chapters will be written into any output file.\n")));
+
+    delete g_kax_chapters;
+    g_kax_chapters     = NULL;
+    s_max_chapter_size = 0;
+
+    return;
+  }
+
+  s_kax_chapters_void = new EbmlVoid;
+  s_kax_chapters_void->SetSize(s_max_chapter_size + 100);
+  s_kax_chapters_void->Render(*s_out);
+}
+
+/** \brief Prepare tag elements for rendering
+
+    Adds missing mandatory elements to the tag structures and sorts
+    them. Also determines the maximum size needed for rendering the
+    tags.
+
+    WebM compliant files must not contain tags. This function
+    issues a warning and invalidates the tags if this is the case.
+ */
+static void
+prepare_tags_for_rendering() {
+  if (NULL == s_kax_tags)
+    return;
+
+  if (outputting_webm()) {
+    mxwarn(boost::format(Y("Tags are not allowed in WebM compliant files. No tags will be written into any output file.\n")));
+
+    delete s_kax_tags;
+    s_kax_tags  = NULL;
+    g_tags_size = 0;
+
+    return;
+  }
+
+  fix_mandatory_tag_elements(s_kax_tags);
+  sort_ebml_master(s_kax_tags);
+  if (!s_kax_tags->CheckMandatory())
+    mxerror(boost::format(Y("Some tag elements are missing (this error should not have occured - another similar error should have occured earlier). %1%\n")) % BUGMSG);
+
+  s_kax_tags->UpdateSize();
+  g_tags_size = s_kax_tags->ElementSize();
+}
+
 /** \brief Creates the next output file
 
    Creates a new file name depending on the split settings. Opens that
@@ -1266,24 +1340,9 @@ create_next_output_file() {
   g_cluster_helper->set_output(s_out);
   render_headers(s_out);
   render_attachments(s_out);
-
-  if (0 < s_max_chapter_size) {
-    s_kax_chapters_void = new EbmlVoid;
-    s_kax_chapters_void->SetSize(s_max_chapter_size + 100);
-    s_kax_chapters_void->Render(*s_out);
-  }
-
+  render_chapter_void_placeholder();
   add_tags_from_cue_chapters();
-
-  if (NULL != s_kax_tags) {
-    fix_mandatory_tag_elements(s_kax_tags);
-    sort_ebml_master(s_kax_tags);
-    if (!s_kax_tags->CheckMandatory())
-      mxerror(boost::format(Y("Some tag elements are missing (this error should not have occured - another similar error should have occured earlier). %1%\n")) % BUGMSG);
-
-    s_kax_tags->UpdateSize();
-    g_tags_size = s_kax_tags->ElementSize();
-  }
+  prepare_tags_for_rendering();
 
   g_file_num++;
 }
@@ -1302,7 +1361,7 @@ finish_file(bool last_file) {
 
   // Render the track headers a second time if the user has requested that.
   if (hack_engaged(ENGAGE_WRITE_HEADERS_TWICE)) {
-    EbmlElement *second_tracks = g_kax_tracks.Clone();
+    EbmlElement *second_tracks = g_kax_tracks->Clone();
     second_tracks->Render(*s_out);
     g_kax_sh_main->IndexThis(*second_tracks, *g_kax_segment);
     delete second_tracks;
@@ -1460,7 +1519,7 @@ finish_file(bool last_file) {
 
   if ((g_kax_sh_main->ListSize() > 0) && !hack_engaged(ENGAGE_NO_META_SEEK)) {
     g_kax_sh_main->UpdateSize();
-    if (s_kax_sh_void->ReplaceWith(*g_kax_sh_main, *s_out, true) == 0)
+    if (s_kax_sh_void->ReplaceWith(*g_kax_sh_main, *s_out, true) == INVALID_FILEPOS_T)
       mxwarn(boost::format(Y("This should REALLY not have happened. The space reserved for the first meta seek element was too small. Size needed: %1%. %2%\n"))
              % g_kax_sh_main->ElementSize() % BUGMSG);
   }
@@ -1857,4 +1916,8 @@ cleanup() {
   g_kax_info_chap = NULL;
 
   g_forced_seguids.clear();
+
+  delete g_kax_tracks;
+  g_kax_tracks = NULL;
+
 }
