@@ -36,7 +36,7 @@
 #include "merge/mkvmerge.h"
 #include "merge/output_control.h"
 #include "merge/pr_generic.h"
-
+#include "merge/webm.h"
 
 #define TRACK_TYPE_TO_DEFTRACK_TYPE(track_type)      \
   (  track_audio == track_type ? DEFTRACK_TYPE_AUDIO \
@@ -594,7 +594,7 @@ generic_packetizer_c::set_headers() {
     ptzrs_in_header_order.push_back(this);
 
   if (NULL == m_track_entry) {
-    m_track_entry    = NULL == g_kax_last_entry ? &GetChild<KaxTrackEntry>(g_kax_tracks) : &GetNextChild<KaxTrackEntry>(g_kax_tracks, *g_kax_last_entry);
+    m_track_entry    = NULL == g_kax_last_entry ? &GetChild<KaxTrackEntry>(g_kax_tracks) : &GetNextChild<KaxTrackEntry>(*g_kax_tracks, *g_kax_last_entry);
     g_kax_last_entry = m_track_entry;
     m_track_entry->SetGlobalTimecodeScale((int64_t)g_timecode_scale);
   }
@@ -1008,7 +1008,7 @@ generic_packetizer_c::apply_factory_full_queueing(packet_cptr_di &p_start) {
     }
 
     if (needs_sorting)
-      sort(sorter.begin(), sorter.end());
+      std::sort(sorter.begin(), sorter.end());
 
     // Finally apply the factory.
     for (i = 0; sorter.size() > i; ++i)
@@ -1107,6 +1107,11 @@ generic_packetizer_c::display_dimensions_or_aspect_ratio_set() {
   return m_ti.display_dimensions_or_aspect_ratio_set();
 }
 
+bool
+generic_packetizer_c::is_compatible_with(output_compatibility_e compatibility) {
+  return OC_MATROSKA == compatibility;
+}
+
 //--------------------------------------------------------------------
 
 #define add_all_requested_track_ids(type, container)                                              \
@@ -1231,6 +1236,9 @@ generic_reader_c::attachment_requested(int64_t id) {
 
 int
 generic_reader_c::add_packetizer(generic_packetizer_c *ptzr) {
+  if (outputting_webm() && !ptzr->is_compatible_with(OC_WEBM))
+    mxerror(boost::format(Y("The codec type '%1%' cannot be used in a WebM compliant file.\n")) % ptzr->get_format_name());
+
   m_reader_packetizers.push_back(ptzr);
   m_used_track_ids.push_back(ptzr->m_ti.m_id);
   if (!m_appending)
