@@ -35,6 +35,7 @@
 #include "common/strings/editing.h"
 #include "merge/packet.h"
 #include "merge/timecode_factory.h"
+#include "merge/webm.h"
 
 using namespace libmatroska;
 
@@ -589,6 +590,8 @@ public:
   virtual void apply_factory_full_queueing(packet_cptr_di &p_start);
 
   virtual bool display_dimensions_or_aspect_ratio_set();
+
+  virtual bool is_compatible_with(output_compatibility_e compatibility);
 };
 
 extern std::vector<generic_packetizer_c *> ptzrs_in_header_order;
