@@ -397,6 +397,8 @@ mmg_dialog::load(wxString file_name,
   attachments_page->load(&cfg, version);
   global_page->load(&cfg, version);
 
+  handle_webm_mode(global_page->cb_webm_mode->IsChecked());
+
   if (!used_for_jobs) {
     set_last_settings_in_menu(file_name);
     set_status_bar(Z("Configuration loaded."));
@@ -579,7 +581,7 @@ mmg_dialog::on_run(wxCommandEvent &evt) {
                        "The chapters present in the editor will NOT be muxed into the output file. "
                        "Only the various 'save' functions from the chapter editor menu will cause the chapters to be written to the hard disk.\n\n"
                        "Do you really want to continue muxing?\n\n"
-                       "Note: This warning can be deactivated on the 'settings' page. "
+                       "Note: This warning can be deactivated in the 'options' dialog. "
                        "Turn off the 'Warn about usage...' option."),
                      Z("Chapter editor is not empty"),
                      wxYES_NO | wxICON_QUESTION) != wxYES)
@@ -827,6 +829,9 @@ mmg_dialog::update_command_line() {
     clargs.Add(options.priority);
   }
 
+  if (global_page->cb_webm_mode->IsChecked())
+    clargs.Add(wxT("--webm"));
+
   unsigned int fidx;
   for (fidx = 0; files.size() > fidx; fidx++) {
     mmg_file_cptr &f    = files[fidx];
@@ -1289,16 +1294,6 @@ mmg_dialog::set_output_maybe(const wxString &new_output) {
   if (!options.autoset_output_filename || new_output.empty())
     return;
 
-  bool has_video = false, has_audio = false;
-
-  foreach(mmg_track_t *t, tracks) {
-    if (t->is_video()) {
-      has_video = true;
-      break;
-    } else if (t->is_audio())
-      has_audio = true;
-  }
-
   wxFileName source_file_name(tc_output->GetValue().IsEmpty() ? new_output : tc_output->GetValue());
   wxString output_dir;
   if (ODM_PREVIOUS == options.output_directory_mode)
@@ -1315,7 +1310,7 @@ mmg_dialog::set_output_maybe(const wxString &new_output) {
   while (true) {
     output_file_name = dir;
     output_file_name.SetName(source_file_name.GetName() + (0 == idx ? wxT("") : wxString::Format(wxT(" (%u)"), idx)));
-    output_file_name.SetExt(has_video ? wxU("mkv") : has_audio ? wxU("mka") : wxU("mks"));
+    output_file_name.SetExt(suggest_file_name_extension());
 
     if (!output_file_name.FileExists())
       break;
@@ -1326,6 +1321,24 @@ mmg_dialog::set_output_maybe(const wxString &new_output) {
   tc_output->SetValue(output_file_name.GetFullPath());
 }
 
+wxString
+mmg_dialog::suggest_file_name_extension() {
+  bool has_video = false, has_audio = false;
+
+  foreach(mmg_track_t *t, tracks) {
+    if (t->is_video()) {
+      has_video = true;
+      break;
+    } else if (t->is_audio())
+      has_audio = true;
+  }
+
+  return global_page->cb_webm_mode->IsChecked() ? wxU("webm")
+       : has_video                              ? wxU("mkv")
+       : has_audio                              ? wxU("mka")
+       :                                          wxU("mks");
+}
+
 void
 mmg_dialog::remove_output_filename() {
   if (!options.autoset_output_filename)
@@ -1622,6 +1635,15 @@ mmg_dialog::set_on_top(bool on_top) {
   SetWindowStyleFlag(style);
 }
 
+void
+mmg_dialog::handle_webm_mode(bool enabled) {
+  if (!tc_output->IsEmpty())
+    tc_output->SetValue(tc_output->GetValue().BeforeLast(wxT('.')) + wxT(".") + suggest_file_name_extension());
+
+  input_page->handle_webm_mode(enabled);
+  global_page->handle_webm_mode(enabled);
+}
+
 void
 mmg_dialog::restore_on_top() {
   set_on_top(options.on_top);
@@ -1708,6 +1730,14 @@ mmg_dialog::query_mkvmerge_capabilities() {
         capabilities[parts[0]] = parts[1];
     }
   }
+
+  if (0 != compare_current_version_to(wxMB(capabilities[wxT("VERSION")])))
+    wxMessageBox(wxString::Format(Z("The GUI is configured to use the mkvmerge executable from a different version (%s) than the GUI itself (%s). "
+                                    "This is not supported but will not be prevented either. "
+                                    "You should change the mkvmerge executable in the preferences dialog."),
+                                  capabilities[wxT("VERSION")].c_str(), wxUCS(get_version_info("mkvmerge GUI", true))),
+                 Z("Incompatible mkvmerge version"),
+                 wxCENTER | wxOK | wxICON_ERROR);
 }
 
 IMPLEMENT_CLASS(mmg_dialog, wxFrame);
