@@ -33,6 +33,7 @@
 #include "common/strings/editing.h"
 #include "common/strings/formatting.h"
 #include "common/strings/parsing.h"
+#include "mmg/message_dialog.h"
 #include "mmg/mmg.h"
 #include "mmg/mmg_dialog.h"
 #include "mmg/tabs/attachments.h"
@@ -237,11 +238,12 @@ tab_input::setup_file_type_filter() {
   file_types.push_back(file_type_t(Z("DTS/DTS-HD (Digital Theater System)"), wxU("dts dtshd dts-hd")));
   if (capabilities[wxT("FLAC")] == wxT("true"))
     file_types.push_back(file_type_t(Z("FLAC (Free Lossless Audio Codec)"),  wxU("flac ogg")));
+  file_types.push_back(file_type_t(Z("IVF with VP8 video files"),            wxU("ivf")));
   file_types.push_back(file_type_t(Z("MP4 audio/video files"),               wxU("mp4")));
   file_types.push_back(file_type_t(Z("MPEG audio files"),                    wxU("mp2 mp3")));
   file_types.push_back(file_type_t(Z("MPEG program streams"),                wxU("mpg mpeg m2v evo evob vob")));
   file_types.push_back(file_type_t(Z("MPEG video elementary streams"),       wxU("m1v m2v")));
-  file_types.push_back(file_type_t(Z("Matroska audio/video files"),          wxU("mka mks mkv")));
+  file_types.push_back(file_type_t(Z("Matroska audio/video files"),          wxU("mka mks mkv webm webmv webma")));
   file_types.push_back(file_type_t(Z("QuickTime audio/video files"),         wxU("mov")));
   file_types.push_back(file_type_t(Z("Ogg/OGM audio/video files"),           wxU("ogg ogm")));
   file_types.push_back(file_type_t(Z("RealMedia audio/video files"),         wxU("ra ram rm rmvb rv")));
@@ -250,10 +252,11 @@ tab_input::setup_file_type_filter() {
   file_types.push_back(file_type_t(Z("TTA (The lossless True Audio codec)"), wxU("tta")));
   file_types.push_back(file_type_t(Z("USF text subtitles"),                  wxU("usf xml")));
   file_types.push_back(file_type_t(Z("VC1 elementary streams"),              wxU("vc1")));
+  file_types.push_back(file_type_t(Z("VobButtons"),                          wxU("btn")));
   file_types.push_back(file_type_t(Z("VobSub subtitles"),                    wxU("idx")));
   file_types.push_back(file_type_t(Z("WAVE (uncompressed PCM audio)"),       wxU("wav")));
   file_types.push_back(file_type_t(Z("WAVPACK v4 audio"),                    wxU("wv")));
-  file_types.push_back(file_type_t(Z("VobButtons"),                          wxU("btn")));
+  file_types.push_back(file_type_t(Z("WebM audio/video files"),              wxU("webm webmv webma")));
 
   std::map<wxString, bool> all_extensions_map;
   wxString filters;
@@ -368,6 +371,8 @@ tab_input::add_file(const wxString &file_name,
 
   wxRemoveFile(opt_file_name);
 
+  wxString error_message, error_heading;
+
   if (3 == result) {
     wxString container = Z("unknown");
 
@@ -382,20 +387,32 @@ tab_input::add_file(const wxString &file_name,
     return;
 
   } else if ((0 > result) || (1 < result)) {
-    name.Printf(Z("File identification failed for '%s'. Return code: %d\n\n"), file_name.c_str(), result);
     for (i = 0; i < output.Count(); i++)
-      name += break_line(output[i]) + wxT("\n");
-    name += wxT("\n");
+      error_message += output[i] + wxT("\n");
+    error_message += wxT("\n");
     for (i = 0; i < errors.Count(); i++)
-      name += break_line(errors[i]) + wxT("\n");
-    wxMessageBox(name, Z("File identification failed"), wxOK | wxCENTER | wxICON_ERROR);
-    return;
+      error_message += errors[i] + wxT("\n");
+
+    error_heading.Printf(Z("File identification failed for '%s'. Return code: %d"), file_name.c_str(), result);
 
   } else if (0 < result) {
-    name.Printf(Z("File identification failed. Return code: %d. Errno: %d (%s). Make sure that you've selected a mkvmerge executable in the settings dialog."),
-                result, errno, wxUCS(strerror(errno)));
-    break_line(name, 60);
-    wxMessageBox(name, Z("File identification failed"), wxOK | wxCENTER | wxICON_ERROR);
+    error_message.Printf(Z("File identification failed. Return code: %d. Errno: %d (%s). Make sure that you've selected a mkvmerge executable in the settings dialog."),
+                         result, errno, wxUCS(strerror(errno)));
+    error_heading = Z("File identification failed");
+  }
+
+  if (!error_message.IsEmpty()) {
+    error_message =
+        Z("Command line used:")
+      + wxT("\n\n")
+      + wxString::Format(wxT("\"%s\" --output-charset UTF-8 --identify-for-mmg \"%s\""), mdlg->options.mkvmerge.c_str(), file_name.c_str())
+      + wxT("\n\n")
+      + Z("Output:")
+      + wxT("\n\n")
+      + error_message;
+
+    message_dialog::show(this, Z("File identification failed"), error_heading, error_message);
+
     return;
   }
 
@@ -432,8 +449,7 @@ tab_input::add_file(const wxString &file_name,
         track->type = '?';
 
       parse_int(wxMB(id), track->id);
-      track->ctype   = exact;
-      track->enabled = true;
+      track->ctype = exact;
 
       if ('a' == track->type)
         track->delay = delay_from_file_name;
@@ -533,6 +549,8 @@ tab_input::add_file(const wxString &file_name,
         file->container = FILE_TYPE_DIRAC;
       else if (container == wxT("DTS"))
         file->container = FILE_TYPE_DTS;
+      else if (container == wxT("IVF"))
+        file->container = FILE_TYPE_IVF;
       else if (container == wxT("Matroska"))
         file->container = FILE_TYPE_MATROSKA;
       else if (container == wxT("MP2/MP3"))
@@ -667,7 +685,7 @@ tab_input::add_file(const wxString &file_name,
     int new_track_pos;
 
     mmg_track_cptr &t = file->tracks[i];
-    t->enabled        = true;
+    t->enabled        = !mdlg->global_page->cb_webm_mode->IsChecked() || t->is_webm_compatible();
     t->source         = new_file_pos;
 
     // Look for a place to insert this new track. If the file is "added" then
@@ -700,7 +718,7 @@ tab_input::add_file(const wxString &file_name,
 
     tracks.insert(tracks.begin() + new_track_pos, t.get_object());
     clb_tracks->Insert(t->create_label(), new_track_pos);
-    clb_tracks->Check(new_track_pos, true);
+    clb_tracks->Check(new_track_pos, t->enabled);
   }
 
   if (!file->attached_files.empty())
@@ -955,8 +973,14 @@ tab_input::on_track_selected(wxCommandEvent &evt) {
 void
 tab_input::on_track_enabled(wxCommandEvent &evt) {
   unsigned int i;
-  for (i = 0; i < tracks.size(); i++)
+  for (i = 0; i < tracks.size(); i++) {
+    if (mdlg->global_page->cb_webm_mode->IsChecked() && clb_tracks->IsChecked(i) && !tracks[i]->is_webm_compatible()) {
+      wxMessageBox(Z("This track is not compatible with the WebM mode and cannot be enabled."), Z("Incompatible track"), wxOK | wxCENTER | wxICON_ERROR);
+      clb_tracks->Check(i, false);
+    }
+
     tracks[i]->enabled = clb_tracks->IsChecked(i);
+  }
 }
 
 void
@@ -1402,6 +1426,20 @@ tab_input::validate_settings() {
   return true;
 }
 
+void
+tab_input::handle_webm_mode(bool enabled) {
+  if (enabled) {
+    unsigned int i;
+    for (i = 0; tracks.size() > i; ++i) {
+      if (tracks[i]->is_webm_compatible())
+        continue;
+
+      tracks[i]->enabled = false;
+      clb_tracks->Check(i, false);
+    }
+  }
+}
+
 IMPLEMENT_CLASS(tab_input, wxPanel);
 BEGIN_EVENT_TABLE(tab_input, wxPanel)
   EVT_BUTTON(ID_B_ADDFILE,          tab_input::on_add_file)
