@@ -12,18 +12,13 @@
    Modified by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#include "os.h"
+#include "common/common_pch.h"
 
-#include <stdlib.h>
-#include <stdio.h>
-#include <string.h>
-#include <errno.h>
-
-#include "pr_generic.h"
-#include "dts_common.h"
-#include "matroska.h"
-#include "output_control.h"
-#include "p_dts.h"
+#include "common/dts.h"
+#include "common/matroska.h"
+#include "merge/output_control.h"
+#include "merge/pr_generic.h"
+#include "output/p_dts.h"
 
 using namespace libmatroska;
 
@@ -101,7 +96,10 @@ dts_packetizer_c::get_dts_packet(dts_header_t &dtsheader) {
     m_first_header           = dtsheader;
     m_previous_header        = dtsheader;
     m_get_first_header_later = false;
-    set_headers();
+
+    if (!m_reader->m_appending)
+      set_headers();
+
     rerender_track_headers();
   }
 
@@ -122,7 +120,7 @@ dts_packetizer_c::get_dts_packet(dts_header_t &dtsheader) {
       }
 
     if (!all_zeroes)
-      mxwarn_tid(ti.fname, ti.id, boost::format(Y("Skipping %1% bytes (no valid DTS header found). This might cause audio/video desynchronisation.\n")) % pos);
+      mxwarn_tid(m_ti.m_fname, m_ti.m_id, boost::format(Y("Skipping %1% bytes (no valid DTS header found). This might cause audio/video desynchronisation.\n")) % pos);
   }
 
   unsigned char *buf = (unsigned char *)safememdup(m_packet_buffer + pos, dtsheader.frame_byte_size);
@@ -150,7 +148,7 @@ dts_packetizer_c::process(packet_cptr packet) {
   dts_header_t dtsheader;
   unsigned char *dts_packet;
 
-  add_to_buffer(packet->data->get(), packet->data->get_size());
+  add_to_buffer(packet->data->get_buffer(), packet->data->get_size());
   while ((dts_packet = get_dts_packet(dtsheader)) != NULL) {
     int64_t new_timecode = -1 == packet->timecode ? (int64_t)(((double)m_samples_written * 1000000000.0) / ((double)dtsheader.core_sampling_frequency)) : packet->timecode;
 
@@ -165,7 +163,7 @@ dts_packetizer_c::process(packet_cptr packet) {
 
 connection_result_e
 dts_packetizer_c::can_connect_to(generic_packetizer_c *src,
-                                 string &error_message) {
+                                 std::string &error_message) {
   dts_packetizer_c *dsrc = dynamic_cast<dts_packetizer_c *>(src);
   if (NULL == dsrc)
     return CAN_CONNECT_NO_FORMAT;
