@@ -6,8 +6,6 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: p_kate.h 3112 2005-10-09 09:55:53Z mosu $
-
    class definition for the Kate packetizer
 
    Written by ogg.k.ogg.k <ogg.k.ogg.k@googlemail.com>.
@@ -17,24 +15,22 @@
 #ifndef __P_KATE_H
 #define __P_KATE_H
 
-#include "os.h"
+#include "common/common_pch.h"
 
-#include "common.h"
-#include "pr_generic.h"
-#include "smart_pointers.h"
-#include "kate_common.h"
+#include "merge/pr_generic.h"
+#include "common/kate.h"
 
 class kate_packetizer_c: public generic_packetizer_c {
 private:
-  vector<memory_cptr> headers;
-  memory_cptr global_data;
+  std::vector<memory_cptr> m_headers;
+  memory_cptr m_global_data;
 
-  kate_identification_header_t kate_id;
+  kate_identification_header_t m_kate_id;
 
-  int64_t last_timecode;
+  int64_t m_previous_timecode;
 
 public:
-  kate_packetizer_c(generic_reader_c *_reader, const void *_global_data, int _global_size, track_info_c &_ti) throw (error_c);
+  kate_packetizer_c(generic_reader_c *p_reader, track_info_c &p_ti, const void *global_data, int global_size) throw (error_c);
   virtual ~kate_packetizer_c();
 
   virtual int process(packet_cptr packet);
@@ -43,8 +39,7 @@ public:
   virtual const char *get_format_name() {
     return "Kate";
   }
-  virtual connection_result_e can_connect_to(generic_packetizer_c *src, string &error_message);
+  virtual connection_result_e can_connect_to(generic_packetizer_c *src, std::string &error_message);
 };
 
-
 #endif  // __P_KATE_H
