@@ -6,25 +6,17 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: p_pcm.cpp 3950 2008-09-30 22:35:14Z mosu $
-
    PCM output module
 
    Written by Moritz Bunkus <moritz@bunkus.org>.
    Patches by Robert Millan <rmh@aybabtu.com>.
 */
 
-#include "os.h"
+#include "common/common_pch.h"
 
-#include <stdlib.h>
-#include <stdio.h>
-#include <string.h>
-#include <errno.h>
-
-#include "common.h"
-#include "pr_generic.h"
-#include "p_pcm.h"
-#include "matroska.h"
+#include "common/matroska.h"
+#include "merge/pr_generic.h"
+#include "output/p_pcm.h"
 
 using namespace libmatroska;
 
@@ -43,9 +35,10 @@ pcm_packetizer_c::pcm_packetizer_c(generic_reader_c *p_reader,
   , m_channels(channels)
   , m_bits_per_sample(bits_per_sample)
   , m_packet_size(0)
-  , m_bytes_output(0)
+  , m_samples_output(0)
   , m_big_endian(big_endian)
   , m_ieee_float(ieee_float)
+  , m_s2tc(1000000000ll, m_samples_per_sec)
 {
 
   int i;
@@ -53,17 +46,17 @@ pcm_packetizer_c::pcm_packetizer_c(generic_reader_c *p_reader,
     if ((m_samples_per_sec % i) == 0)
       break;
 
-  if ((2 == i) && ((m_packet_size % 5) == 0))
+  if ((2 == i) && ((m_samples_per_sec % 5) == 0))
     i = 5;
 
-  m_packet_size = samples_per_sec / i;
+  m_samples_per_packet = samples_per_sec / i;
 
   set_track_type(track_audio);
-  set_track_default_duration((int64_t)(1000000000.0 * m_packet_size / m_samples_per_sec));
+  set_track_default_duration((int64_t)(1000000000.0 * m_samples_per_packet / m_samples_per_sec));
 
   /* It could happen that (channels * bits_per_sample < 8).  Because of this,
      we mustn't divide by 8 in the same line, or the result would be hosed. */
-  m_packet_size *= m_channels * m_bits_per_sample;
+  m_packet_size  = m_samples_per_packet * m_channels * m_bits_per_sample;
   m_packet_size /= 8;
 }
 
@@ -90,14 +83,13 @@ pcm_packetizer_c::set_headers() {
 
 int
 pcm_packetizer_c::process(packet_cptr packet) {
-  m_buffer.add(packet->data->get(), packet->data->get_size());
+  m_buffer.add(packet->data->get_buffer(), packet->data->get_size());
 
   while (m_buffer.get_size() >= m_packet_size) {
-    add_packet(new packet_t(new memory_c(m_buffer.get_buffer(), m_packet_size, false), (int64_t)m_bytes_output * 1000000000ll / m_bytes_per_second,
-                            (int64_t)m_packet_size * 1000000000ll / m_bytes_per_second));
+    add_packet(new packet_t(new memory_c(m_buffer.get_buffer(), m_packet_size, false), m_samples_output * m_s2tc, m_samples_per_packet * m_s2tc));
 
     m_buffer.remove(m_packet_size);
-    m_bytes_output += m_packet_size;
+    m_samples_output += m_samples_per_packet;
   }
 
   return FILE_STATUS_MOREDATA;
@@ -107,10 +99,10 @@ void
 pcm_packetizer_c::flush() {
   uint32_t size = m_buffer.get_size();
   if (0 < size) {
-    add_packet(new packet_t(new memory_c(m_buffer.get_buffer(), size, false),
-                            (int64_t)m_bytes_output * 1000000000ll / m_bytes_per_second,
-                            (int64_t)size * 1000000000ll / m_bytes_per_second));
-    m_bytes_output += size;
+    int64_t samples_here = size * 8 / m_channels / m_bits_per_sample;
+    add_packet(new packet_t(new memory_c(m_buffer.get_buffer(), size, false), m_samples_output * m_s2tc, samples_here * m_s2tc));
+
+    m_samples_output += samples_here;
     m_buffer.remove(size);
   }
 
@@ -119,7 +111,7 @@ pcm_packetizer_c::flush() {
 
 connection_result_e
 pcm_packetizer_c::can_connect_to(generic_packetizer_c *src,
-                                 string &error_message) {
+                                 std::string &error_message) {
   pcm_packetizer_c *psrc = dynamic_cast<pcm_packetizer_c *>(src);
   if (NULL == psrc)
     return CAN_CONNECT_NO_FORMAT;
