@@ -11,13 +11,8 @@
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#include "common/os.h"
+#include "common/common_pch.h"
 
-#include <boost/regex.hpp>
-#include <string>
-
-#include "common/common.h"
-#include "common/locale.h"
 #include "common/matroska.h"
 #include "merge/pr_generic.h"
 #include "output/p_textsubs.h"
@@ -43,7 +38,7 @@ textsubs_packetizer_c::textsubs_packetizer_c(generic_reader_c *p_reader,
   , m_recode(recode)
 {
   if (m_recode)
-    m_cc_utf8 = charset_converter_c::init((ti.sub_charset != "") || !is_utf8 ? ti.sub_charset : "UTF-8");
+    m_cc_utf8 = charset_converter_c::init((m_ti.m_sub_charset != "") || !is_utf8 ? m_ti.m_sub_charset : "UTF-8");
 
   set_track_type(track_subtitle);
   if (m_codec_id == MKV_S_TEXTUSF)
@@ -62,13 +57,13 @@ textsubs_packetizer_c::set_headers() {
 
   generic_packetizer_c::set_headers();
 
-  track_entry->EnableLacing(false);
+  m_track_entry->EnableLacing(false);
 }
 
 int
 textsubs_packetizer_c::process(packet_cptr packet) {
   if (0 > packet->duration) {
-    mxwarn_tid(ti.fname, ti.id, Y("Ignoring an entry which starts after it ends.\n"));
+    mxwarn_tid(m_ti.m_fname, m_ti.m_id, Y("Ignoring an entry which starts after it ends.\n"));
     return FILE_STATUS_MOREDATA;
   }
 
@@ -97,10 +92,10 @@ textsubs_packetizer_c::can_connect_to(generic_packetizer_c *src,
   if (NULL == psrc)
     return CAN_CONNECT_NO_FORMAT;
 
-  if (   ((NULL == ti.private_data) && (NULL != src->ti.private_data))
-      || ((NULL != ti.private_data) && (NULL == src->ti.private_data))
-      || (ti.private_size != src->ti.private_size)) {
-    error_message = (boost::format(Y("The codec's private data does not match (lengths: %1% and %2%).")) % ti.private_size % src->ti.private_size).str();
+  if (   ((NULL == m_ti.m_private_data) && (NULL != src->m_ti.m_private_data))
+      || ((NULL != m_ti.m_private_data) && (NULL == src->m_ti.m_private_data))
+      || (m_ti.m_private_size != src->m_ti.m_private_size)) {
+    error_message = (boost::format(Y("The codec's private data does not match (lengths: %1% and %2%).")) % m_ti.m_private_size % src->m_ti.m_private_size).str();
     return CAN_CONNECT_MAYBE_CODECPRIVATE;
   }
 
