@@ -6,8 +6,6 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: p_textsubs.h 3838 2008-08-21 15:04:24Z mosu $
-
    class definition for the simple text subtitle packetizer
 
    Written by Moritz Bunkus <moritz@bunkus.org>.
@@ -16,23 +14,20 @@
 #ifndef __P_TEXTSUBS_H
 #define __P_TEXTSUBS_H
 
-#include "os.h"
+#include "common/common_pch.h"
 
-#include "common.h"
-#include "pr_generic.h"
-#include "smart_pointers.h"
+#include "merge/pr_generic.h"
 
 class textsubs_packetizer_c: public generic_packetizer_c {
 private:
-  int packetno, cc_utf8;
-  memory_cptr global_data;
-  string codec_id;
-  bool recode;
+  int m_packetno;
+  charset_converter_cptr m_cc_utf8;
+  memory_cptr m_global_data;
+  std::string m_codec_id;
+  bool m_recode;
 
 public:
-  textsubs_packetizer_c(generic_reader_c *_reader, const char *_codec_id,
-                        const void *_global_data, int _global_size,
-                        bool _recode, bool is_utf8, track_info_c &_ti)
+  textsubs_packetizer_c(generic_reader_c *p_reader, track_info_c &p_ti, const char *codec_id, const void *global_data, int global_size, bool recode, bool is_utf8)
     throw (error_c);
   virtual ~textsubs_packetizer_c();
 
@@ -42,9 +37,10 @@ public:
   virtual const char *get_format_name() {
     return "text subtitle";
   }
-  virtual connection_result_e can_connect_to(generic_packetizer_c *src,
-                                             string &error_message);
+  virtual connection_result_e can_connect_to(generic_packetizer_c *src, std::string &error_message);
+
+private:
+  static boost::regex s_re_remove_cr, s_re_translate_nl, s_re_remove_trailing_nl;
 };
 
-
 #endif  // __P_TEXTSUBS_H
