@@ -6,23 +6,21 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: p_vobbtn.cpp 3950 2008-09-30 22:35:14Z mosu $
-
    VobBtn packetizer
 
    Written by Steve Lhomme <steve.lhomme@free.fr>.
    Modified by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#include "os.h"
+#include "common/common_pch.h"
 
 #include <matroska/KaxContentEncoding.h>
 
-#include "common.h"
-#include "compression.h"
-#include "matroska.h"
-#include "mm_io.h"
-#include "p_vobbtn.h"
+#include "common/compression.h"
+#include "common/endian.h"
+#include "common/matroska.h"
+#include "common/mm_io.h"
+#include "output/p_vobbtn.h"
 
 using namespace libmatroska;
 
@@ -52,13 +50,13 @@ vobbtn_packetizer_c::set_headers() {
 
   generic_packetizer_c::set_headers();
 
-  track_entry->EnableLacing(false);
+  m_track_entry->EnableLacing(false);
 }
 
 int
 vobbtn_packetizer_c::process(packet_cptr packet) {
-  uint32_t vobu_start = get_uint32_be(packet->data->get() + 0x0d);
-  uint32_t vobu_end   = get_uint32_be(packet->data->get() + 0x11);
+  uint32_t vobu_start = get_uint32_be(packet->data->get_buffer() + 0x0d);
+  uint32_t vobu_end   = get_uint32_be(packet->data->get_buffer() + 0x11);
 
   packet->duration = (int64_t)(100000.0 * (float)(vobu_end - vobu_start) / 9);
   if (-1 == packet->timecode) {
@@ -74,7 +72,7 @@ vobbtn_packetizer_c::process(packet_cptr packet) {
 
 connection_result_e
 vobbtn_packetizer_c::can_connect_to(generic_packetizer_c *src,
-                                    string &error_message) {
+                                    std::string &error_message) {
   vobbtn_packetizer_c *vsrc = dynamic_cast<vobbtn_packetizer_c *>(src);
   if (NULL == vsrc)
     return CAN_CONNECT_NO_FORMAT;
