@@ -6,8 +6,6 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: p_vobbtn.h 3838 2008-08-21 15:04:24Z mosu $
-
    class definition for the VobBtn output module
 
    Written by Steve Lhomme <steve.lhomme@free.fr>.
@@ -17,20 +15,18 @@
 #ifndef __P_VOBBTN_H
 #define __P_VOBBTN_H
 
-#include "os.h"
+#include "common/common_pch.h"
 
-#include "common.h"
-#include "compression.h"
-#include "pr_generic.h"
+#include "common/compression.h"
+#include "merge/pr_generic.h"
 
 class vobbtn_packetizer_c: public generic_packetizer_c {
 protected:
-  int64_t previous_timecode;
-  int width, height;
+  int64_t m_previous_timecode;
+  int m_width, m_height;
 
 public:
-  vobbtn_packetizer_c(generic_reader_c *_reader, int _width, int _height,
-                      track_info_c &_ti) throw (error_c);
+  vobbtn_packetizer_c(generic_reader_c *p_reader, track_info_c &p_ti, int width, int height) throw (error_c);
   virtual ~vobbtn_packetizer_c();
 
   virtual int process(packet_cptr packet);
@@ -39,8 +35,7 @@ public:
   virtual const char *get_format_name() {
     return "VobBtn";
   }
-  virtual connection_result_e can_connect_to(generic_packetizer_c *src,
-                                             string &error_message);
+  virtual connection_result_e can_connect_to(generic_packetizer_c *src, std::string &error_message);
 };
 
 #endif // __P_VOBBTN_H
