@@ -22,6 +22,7 @@ class Test
   end
 
   def unlink_tmp_files
+    return if (ENV["KEEP_TMPFILES"] == "1")
     n = "mkvtoolnix-auto-test-" + $$.to_s + "-"
     Dir.entries("/tmp").each do |e|
       File.unlink("/tmp/#{e}") if ((e =~ /^#{n}/) and
@@ -74,7 +75,7 @@ class Test
   def hash_tmp(erase = true)
     output = hash_file(@tmp)
     if (erase)
-      File.unlink(@tmp) if (File.exists?(@tmp))
+      File.unlink(@tmp) if (File.exists?(@tmp) && (ENV["KEEP_TMPFILES"] != "1"))
       @debug_commands.push("rm #{@tmp}")
       @tmp = nil
     end
@@ -165,7 +166,7 @@ class Results
   def date_added?(name)
     raise "No such result" unless (exist?(name))
     return @results[name]['date_added']
-  end    
+  end
 
   def add(name, hash)
     raise "Test does already exist" if (exist?(name))
@@ -188,7 +189,7 @@ class Results
 end
 
 def main
-  ENV['LC_ALL'] = "en_US.ISO-8859-1"
+  ENV['LC_ALL'] = "en_US.UTF-8"
 
   results = Results.new
 
